<?php
use App\Setting;
use App\Country;
use App\SocialSetting;
use App\Category;
use App\User;
use Spatie\Permission\Models\Permission;
use Illuminate\Support\Facades\Crypt;

function get_setting($key)
{
    $setting = Setting::where('key',$key)->first();
    if($setting)
    {
        return $setting->value;
    }
    return false;
}

function save_setting($key, $name, $value, $type, $group='admin')
{
    $setting = Setting::all();
    $order   = $setting->count() + 1;

    $setting = new Setting;
    $setting->key   = $group.'.'.$key;
    $setting->name  = $name;
    $setting->value = $value;
    $setting->type  = $type;
    $setting->order = $order;
    $setting->group = $group;
    if($setting->save())
    {
        return true;
    }
    
    return false;
}

function countries()
{
    $countries = Country::all();
    if($countries)
    {
        return $countries;
    }
}

function selectHtmlCreate($data= array(),$selected='')
{
    $options = '';
    foreach ($data as $key => $value) 
    {
        if($selected != '' && $value->name == $selected)
        {
            $options .= '<option value="'. $value->name.'" selected>'.$value->name.'</option>';
        }
        else
        {
            $options .= '<option value="'. $value->name.'">'.$value->name.'</option>';
        }
    }
    return $options;
}

function imageUpload($image,$destination_path)
{
    $filename         = time().'.'. $image->getClientOriginalExtension();
    $image->storeAs($destination_path,$filename);
    return $filename;
}

function socials()
{
    $socials = SocialSetting::all();
    if($socials)
    {
        return $socials;
    }
}

function parentCategories()
{
    $categories = Category::all();
    return $categories;
}

function hasRole()
{
    $user = Auth::user();
    $roles = $user->roles->pluck('name')->all();
    return $roles[0];
}

function userDropDown()
{
    $users       = User::all();
    $userHtml    = '<select class="form-control" name="userId" id="userId" onchange="getUserData()" ><option></option>'; 
    foreach ($users as $key => $user) 
    {
        $userHtml .= '<option value="'.$user->id.'">'.$user->first_name. ' '. $user->last_name.'</option>';
    }
    $userHtml    .= '</select>';
    return $userHtml;
}

/* Wix Authorization Code save and genrate access token*/
function wixAuthorizationCode($state, $code, $instanceId)
{
    $user_id    = Crypt::decrypt($state);
    $userObje   = User::find($user_id);
    $appId      = get_setting('admin.appId');
    $secret_Key = get_setting('admin.secret_Key');


    $postData = array("grant_type" => "authorization_code", "client_id" => $appId, "client_secret" => $secret_Key , "code"=> $code);
    $postData = json_encode($postData);

    $curl = curl_init();

    curl_setopt_array($curl, array(
    CURLOPT_URL => "https://www.wix.com/oauth/access",
    CURLOPT_RETURNTRANSFER => true,
    CURLOPT_ENCODING => "",
    CURLOPT_MAXREDIRS => 10,
    CURLOPT_TIMEOUT => 0,
    CURLOPT_SSL_VERIFYHOST => 0,
    CURLOPT_SSL_VERIFYPEER => 0,
    CURLOPT_FOLLOWLOCATION => true,
    CURLOPT_HTTP_VERSION => CURL_HTTP_VERSION_1_1,
    CURLOPT_CUSTOMREQUEST => "POST",
    CURLOPT_POSTFIELDS => $postData,
    CURLOPT_HTTPHEADER => array(
        "Content-Type: application/json",
        ),
    ));

    $response = curl_exec($curl);
    $err = curl_error($curl);

    curl_close($curl);
    if ($err) 
    {
        return "cURL Error #:" . $err;
    } 
    else 
    {
        $tokenResponse  = json_decode($response);
        if($tokenResponse)
        {
            /* Save user auth code and token etc.*/
            $userObje->auth_code     = $code;
            $userObje->instanceId    = $instanceId;
            $userObje->access_token  = $tokenResponse->access_token;
            $userObje->refresh_token = $tokenResponse->refresh_token;
            $userObje->update();
        }
    }

    $curl = curl_init();
    curl_setopt_array($curl, array(
    CURLOPT_URL => "https://www.wix.com/_api/site-apps/v1/site-apps/token-received?access_token=",
    CURLOPT_RETURNTRANSFER => true,
    CURLOPT_ENCODING => "",
    CURLOPT_MAXREDIRS => 10,
    CURLOPT_TIMEOUT => 0,
    CURLOPT_SSL_VERIFYHOST => 0,
    CURLOPT_SSL_VERIFYPEER => 0,
    CURLOPT_FOLLOWLOCATION => true,
    CURLOPT_HTTP_VERSION => CURL_HTTP_VERSION_1_1,
    CURLOPT_CUSTOMREQUEST => "GET",
    CURLOPT_HTTPHEADER => array(
        "Content-Type: application/json",
        ),
    ));

    $response = curl_exec($curl);
    $err = curl_error($curl);

    curl_close($curl);
    if ($err) 
    {
        return "cURL Error #:" . $err;
    } 
    else 
    {
        $response  = json_decode($response);
    }

    return redirect('/')->with('alert-success', 'App install Successfully');
}

/* Wix Refresh access token*/
function wixRefreshToken($user_id)
{
    $userObje   = User::find($user_id);
    $appId      = get_setting('admin.appId');
    $secret_Key = get_setting('admin.secret_Key');


    $postData = array("grant_type" => "refresh_token", "client_id" => $appId, "client_secret" => $secret_Key , "refresh_token"=> $userObje->refresh_token);
    $postData = json_encode($postData);

    $curl = curl_init();

    curl_setopt_array($curl, array(
    CURLOPT_URL => "https://www.wix.com/oauth/access",
    CURLOPT_RETURNTRANSFER => true,
    CURLOPT_ENCODING => "",
    CURLOPT_MAXREDIRS => 10,
    CURLOPT_TIMEOUT => 0,
    CURLOPT_SSL_VERIFYHOST => 0,
    CURLOPT_SSL_VERIFYPEER => 0,
    CURLOPT_FOLLOWLOCATION => true,
    CURLOPT_HTTP_VERSION => CURL_HTTP_VERSION_1_1,
    CURLOPT_CUSTOMREQUEST => "POST",
    CURLOPT_POSTFIELDS => $postData,
    CURLOPT_HTTPHEADER => array(
        "Content-Type: application/json",
        ),
    ));

    $response = curl_exec($curl);
    $err = curl_error($curl);

    curl_close($curl);
    if ($err) 
    {
        return "cURL Error #:" . $err;
    } 
    else 
    {
        $tokenResponse  = json_decode($response);
        if($tokenResponse)
        {
            /* Save user access token code and refresh token etc.*/
            $userObje->access_token  = $tokenResponse->access_token;
            $userObje->refresh_token = $tokenResponse->refresh_token;
            $userObje->update();
            return $tokenResponse->access_token;
        }
    }
}

/* Wix Universal API call*/
function wixCall($user_id, $url, $mathod, $postData=null)
{
    $accessToken = wixRefreshToken($user_id);
    $options = array(
        CURLOPT_URL => 'https://'.$url,
        CURLOPT_RETURNTRANSFER => true,
        CURLOPT_ENCODING => '',
        CURLOPT_MAXREDIRS => 10,
        CURLOPT_TIMEOUT => 0,
        CURLOPT_SSL_VERIFYHOST => 0,
        CURLOPT_SSL_VERIFYPEER => 0,
        CURLOPT_FOLLOWLOCATION => true,
        CURLOPT_HTTP_VERSION => CURL_HTTP_VERSION_1_1,
        );
    $curl = curl_init();
    curl_setopt_array($curl, $options);
    if($mathod == 'GET')
    {
        curl_setopt_array($curl, array(CURLOPT_CUSTOMREQUEST => 'GET'));
    }
    else if($mathod == 'DELETE')
    {
        curl_setopt_array($curl, array(CURLOPT_CUSTOMREQUEST => 'DELETE'));
    }
    else
    {
        curl_setopt_array($curl, array(
            CURLOPT_CUSTOMREQUEST => "POST",
            CURLOPT_POSTFIELDS => $postData
        ));
    }
    curl_setopt_array($curl, array(CURLOPT_HTTPHEADER => array(
            "Content-Type: application/json",
            'Authorization: '.$accessToken
            ),
        ));

    $response = curl_exec($curl);
    $err = curl_error($curl);
    curl_close($curl);

    if ($err) 
    {
        echo "cURL Error #:" . $err;
        exit();
    } 
    else 
    {
        $return_obj = json_decode($response);
        return $return_obj;
    }
}

/* Gain Avdiamond authorization token */
function getAccess_token()
{
    $auth_url = 'http://auth.avdiamond.com/api/Authorize/GetAccessToken';
    $client_id = '72d6c797-9bd1-4817-ab52-bfe7cf765a48';
    $client_secret = '3bf962a2-aab0-4329-a8e2-d2ff308e768c';
    $redirect = 'http://avdiamond.com/';

    $var =  $auth_url. "?client_id=" . $client_id . "&client_secret=" . $client_secret . "&serverUrl=" . $redirect;
    $curl = curl_init();
    curl_setopt_array($curl, array(CURLOPT_URL => $var, CURLOPT_RETURNTRANSFER => true, CURLOPT_ENCODING => "", CURLOPT_MAXREDIRS => 10, CURLOPT_TIMEOUT => 30000, CURLOPT_SSL_VERIFYHOST => 0,
    CURLOPT_SSL_VERIFYPEER => 0, CURLOPT_HTTP_VERSION => CURL_HTTP_VERSION_1_1, CURLOPT_CUSTOMREQUEST => "POST", CURLOPT_POSTFIELDS => array(), CURLOPT_HTTPHEADER => array("Cache-Control: no-cache",),));
    $response = curl_exec($curl);

    $err = curl_error($curl);
    curl_close($curl);
    if ($err) 
    {
        echo "cURL Error #:" . $err;
    } 
    else 
    {
        $token_data = json_decode($response);
        if($token_data)
        {
            $access_token = $token_data->access_token;
            return $access_token;
        }
        else
        {
            return response()->json(['status' => 'false', 'message' => "Av access token API not responding"]);
        }
    }
}


/* Gain Avdiamond categories */
function getCategories()
{
    $curl = curl_init();

    curl_setopt_array($curl, array(
    CURLOPT_URL => "https://avdiamond.com/api/categories",
    CURLOPT_RETURNTRANSFER => true,
    CURLOPT_ENCODING => "",
    CURLOPT_MAXREDIRS => 10,
    CURLOPT_TIMEOUT => 60,
    CURLOPT_SSL_VERIFYHOST => 0,
    CURLOPT_SSL_VERIFYPEER => 0,
    CURLOPT_FOLLOWLOCATION => true,
    CURLOPT_HTTP_VERSION => CURL_HTTP_VERSION_1_1,
    CURLOPT_CUSTOMREQUEST => "GET",
    CURLOPT_HTTPHEADER => array(
        "Content-Type: application/json",
        "Authorization: Bearer ".getAccess_token(),
        //"Authorization: Bearer ".env("AV_TOKEN"),
    ),
    ));

    $response = curl_exec($curl);
    $err = curl_error($curl);

    curl_close($curl);
    if ($err) 
    {
        return "cURL Error #:" . $err;
    } 
    else 
    {
        return json_decode($response);
    }

}

/* Gain Avdiamond Products */
function getproducts()
{
    $curl = curl_init();

    curl_setopt_array($curl, array(
    CURLOPT_URL => "https://avdiamond.com/api/products",
    CURLOPT_RETURNTRANSFER => true,
    CURLOPT_ENCODING => "",
    CURLOPT_MAXREDIRS => 10,
    CURLOPT_TIMEOUT => 0,
    CURLOPT_SSL_VERIFYHOST => 0,
    CURLOPT_SSL_VERIFYPEER => 0,
    CURLOPT_FOLLOWLOCATION => true,
    CURLOPT_HTTP_VERSION => CURL_HTTP_VERSION_1_1,
    CURLOPT_CUSTOMREQUEST => "GET",
    CURLOPT_HTTPHEADER => array(
        "Content-Type: application/json",
        "Authorization: Bearer ".getAccess_token(),
        //"Authorization: Bearer ".env("AV_TOKEN"),
        ),
    ));

    $response = curl_exec($curl);
    $err = curl_error($curl);

    curl_close($curl);
    if ($err) 
    {
        return "cURL Error #:" . $err;
    } 
    else 
    {
        return json_decode($response);
    }
}


/* Gain avdiamond in stock Products count*/
function getproductsCount()
{
    $curl = curl_init();

    curl_setopt_array($curl, array(
    CURLOPT_URL => "https://avdiamond.com/api/products/count?hide_out_of_stock_products=true",
    CURLOPT_RETURNTRANSFER => true,
    CURLOPT_ENCODING => "",
    CURLOPT_MAXREDIRS => 10,
    CURLOPT_TIMEOUT => 0,
    CURLOPT_SSL_VERIFYHOST => 0,
    CURLOPT_SSL_VERIFYPEER => 0,
    CURLOPT_FOLLOWLOCATION => true,
    CURLOPT_HTTP_VERSION => CURL_HTTP_VERSION_1_1,
    CURLOPT_CUSTOMREQUEST => "GET",
    CURLOPT_HTTPHEADER => array(
        "Content-Type: application/json",
        "Authorization: Bearer ".getAccess_token(),
        //"Authorization: Bearer ".env("AV_TOKEN"),
        ),
    ));

    $response = curl_exec($curl);
    $err = curl_error($curl);

    curl_close($curl);
    if ($err) 
    {
        return "cURL Error #:" . $err;
    } 
    else 
    {
        return json_decode($response);
    }
}


/* Gain avdiamond in stock Products with limit and page*/
function getproducts_with_limt($page,$limit)
{
    $curl = curl_init();

    curl_setopt_array($curl, array(
    CURLOPT_URL => "https://avdiamond.com/api/products?hide_out_of_stock_products=true&page=".$page."&limit=".$limit,
    CURLOPT_RETURNTRANSFER => true,
    CURLOPT_ENCODING => "",
    CURLOPT_MAXREDIRS => 10,
    CURLOPT_TIMEOUT => 0,
    CURLOPT_SSL_VERIFYHOST => 0,
    CURLOPT_SSL_VERIFYPEER => 0,
    CURLOPT_FOLLOWLOCATION => true,
    CURLOPT_HTTP_VERSION => CURL_HTTP_VERSION_1_1,
    CURLOPT_CUSTOMREQUEST => "GET",
    CURLOPT_HTTPHEADER => array(
        "Content-Type: application/json",
        "Authorization: Bearer ".getAccess_token(),
        //"Authorization: Bearer ".env("AV_TOKEN"),
        ),
    ));

    $response = curl_exec($curl);
    $err = curl_error($curl);

    curl_close($curl);
    if ($err) 
    {
        return "cURL Error #:" . $err;
    } 
    else 
    {
        return json_decode($response);
    }
}

/* Gain products whose update within the last 20 minutes */

function getProductsUpdate()
{
    $curl = curl_init();

    curl_setopt_array($curl, array(
    CURLOPT_URL => "http://avdiamond.com/api/getUpdatedProducts?seconds=1200",
    CURLOPT_RETURNTRANSFER => true,
    CURLOPT_ENCODING => "",
    CURLOPT_MAXREDIRS => 10,
    CURLOPT_TIMEOUT => 0,
    CURLOPT_SSL_VERIFYHOST => 0,
    CURLOPT_SSL_VERIFYPEER => 0,
    CURLOPT_FOLLOWLOCATION => true,
    CURLOPT_HTTP_VERSION => CURL_HTTP_VERSION_1_1,
    CURLOPT_CUSTOMREQUEST => "GET",
    CURLOPT_HTTPHEADER => array(
        "Content-Type: application/json",
        "Authorization: Bearer ".getAccess_token(),
        //"Authorization: Bearer ".env("AV_TOKEN"),
        ),
    ));

    $response = curl_exec($curl);
    $err = curl_error($curl);

    curl_close($curl);
    if ($err) 
    {
        return "cURL Error #:" . $err;
    } 
    else 
    {
        return json_decode($response);
    }
}

/* Gain Avdiamond Products with category*/
function getCatProducts($catid)
{
    $curl = curl_init();
    curl_setopt_array($curl, array(
    CURLOPT_URL => "https://avdiamond.com/api/products?hide_out_of_stock_products=true&category_id=".$catid,
    CURLOPT_RETURNTRANSFER => true,
    CURLOPT_ENCODING => "",
    CURLOPT_MAXREDIRS => 10,
    CURLOPT_TIMEOUT => 0,
    CURLOPT_SSL_VERIFYHOST => 0,
    CURLOPT_SSL_VERIFYPEER => 0,
    CURLOPT_FOLLOWLOCATION => true,
    CURLOPT_HTTP_VERSION => CURL_HTTP_VERSION_1_1,
    CURLOPT_CUSTOMREQUEST => "GET",
    CURLOPT_HTTPHEADER => array(
        "Content-Type: application/json",
        "Authorization: Bearer ".getAccess_token(),
        //"Authorization: Bearer ".env("AV_TOKEN"),
        ),
    ));

    $response = curl_exec($curl);
    $err = curl_error($curl);

    curl_close($curl);
    if ($err) 
    {
        return "cURL Error #:" . $err;
    } 
    else 
    {
        return json_decode($response);
    }
}

/* Gain Avdiamond Products using specific id */
function getSpecificProduct($url)
{
    $request_url = $url;
    $curl = curl_init();

    curl_setopt_array($curl, array(
    CURLOPT_URL => $request_url,
    CURLOPT_RETURNTRANSFER => true,
    CURLOPT_ENCODING => "",
    CURLOPT_MAXREDIRS => 10,
    CURLOPT_TIMEOUT => 0,
    CURLOPT_SSL_VERIFYHOST => 0,
    CURLOPT_SSL_VERIFYPEER => 0,
    CURLOPT_FOLLOWLOCATION => true,
    CURLOPT_HTTP_VERSION => CURL_HTTP_VERSION_1_1,
    CURLOPT_CUSTOMREQUEST => "GET",
    CURLOPT_HTTPHEADER => array(
        "Content-Type: application/json",
        "Authorization: Bearer ".getAccess_token(),
        //"Authorization: Bearer ".env("AV_TOKEN"),
        ),
    ));

    $response = curl_exec($curl);
    $err = curl_error($curl);

    curl_close($curl);
    if ($err) 
    {
        return "cURL Error #:" . $err;
    } 
    else 
    {
        return json_decode($response);
    }
}

?>