<?php

namespace App\Http\Controllers\Auth;

use App\Http\Controllers\Controller;
use App\Providers\RouteServiceProvider;
use App\User;
use App\Address;
use Spatie\Permission\Models\Role;
use Illuminate\Foundation\Auth\RegistersUsers;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Facades\Validator;
use Illuminate\Support\Facades\Crypt;

class RegisterController extends Controller
{
    /*
    |--------------------------------------------------------------------------
    | Register Controller
    |--------------------------------------------------------------------------
    |
    | This controller handles the registration of new users as well as their
    | validation and creation. By default this controller uses a trait to
    | provide this functionality without requiring any additional code.
    |
    */

    use RegistersUsers;

    /**
     * Where to redirect users after registration.
     *
     * @var string
     */
    protected $redirectTo = RouteServiceProvider::HOME;

    /**
     * Create a new controller instance.
     *
     * @return void
     */
    public function __construct()
    {
        $this->middleware('guest');
    }

    /**
     * Get a validator for an incoming registration request.
     *
     * @param  array  $data
     * @return \Illuminate\Contracts\Validation\Validator
     */
    protected function validator(array $data)
    {
        return Validator::make($data, [
            'first_name' => ['required', 'string', 'max:30'],
            'last_name' => ['required', 'string', 'max:30'],
            'email' => ['required', 'string', 'email', 'max:50', 'unique:users'],
            'phone' => ['required', 'numeric', 'digits_between:1,15'],
            'address' => ['required', 'string', 'max:255'],
            'zip' => ['required', 'string', 'max:50'],
            'unit' => ['required', 'string', 'max:50'],
            'company' => ['required', 'string', 'max:50'],
            'country' => ['required', 'string', 'max:100'],
            'state' => ['required', 'string', 'max:100'],
            'city' => ['required', 'string', 'max:100'],
            'account_type' => ['required', 'string'],
            'password' => ['required', 'string', 'min:8', 'confirmed'],
        ]);
    }

    /**
     * Create a new user instance after a valid registration.
     *
     * @param  array  $data
     * @return \App\User
     */
    protected function create(array $data)
    {
        $user = User::create([
            'first_name' => $data['first_name'],
            'last_name' => $data['last_name'],
            'email' => $data['email'],
            'phone' => $data['phone'],
            'password' => Hash::make($data['password']),
        ]);

        $address = new Address;
        $address->user_id = $user->id;
        $address->name    = $data['first_name'].' '.$data['last_name'];
        $address->phone   = $data['phone'];
        $address->company = $data['company'];
        $address->street1 = $data['address'];
        $address->unit    = $data['unit'];
        $address->city    = $data['city'];
        $address->state   = $data['state'];
        $address->country = $data['country'];
        $address->zip     = $data['zip'];
        $address->save();

        $role = Role::where('name',$data['account_type'])->first();
        $user->assignRole([$role->name]);

        if(!empty($data['wix_token']))
        {
            $user->token = $data['wix_token'];
            $user->update();
            
            $token = $data['wix_token'];
            $appId = get_setting('admin.appId');
            $redirectUrl = get_setting('admin.redirectUrl');
            $state = Crypt::encrypt($user->id);
            $redirect = get_setting('admin.wix_installer').'?token='.$token.'&appId='.$appId.'&redirectUrl='.$redirectUrl.'&state='.$state;
            echo "<script>window.open('".$redirect."', '_blank')</script>";
            exit;
            //return redirect($redirect);
        }

        return $user;
    }
}
