<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use Illuminate\Support\Facades\Validator;
use DB;
use Storage;
use Auth;
use Excel;
use File;
use App\Category;
use App\CategoriesFilter;
use App\Product;
use App\Variant;
use App\ProductLog;
use App\ProductUpdateLog;
use App\User;
use Yajra\DataTables\DataTables;

class CategoriesController extends Controller
{
    var $errorSummary = [];
    function __construct()
    {
        $this->middleware('auth');
        $this->middleware('permission:category-list|category-create|category-upload|category-edit|category-delete', ['only' => ['index','store']]);
        $this->middleware('permission:category-create', ['only' => ['create','store']]);
        $this->middleware('permission:category-upload', ['only' => ['upload']]);
        $this->middleware('permission:category-upload-csv', ['only' => ['uploadData']]);
        $this->middleware('permission:category-edit', ['only' => ['edit','update']]);
        $this->middleware('permission:category-update', ['only' => ['categoriesUpdate']]);
        $this->middleware('permission:category-delete', ['only' => ['destroy']]);
        $this->middleware('permission:category-show', ['only' => ['show']]);
        $this->middleware('permission:category-ajax-data', ['only' => ['ajaxCategoryData']]);
    }

    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $pagetitle   = "Categories";
        $breadcrumbs = ["Dashboard", "Categories"];
        $urls        = ['/home', 'categories/category-list'];
        $userRole    = hasRole();
        $userHtml    = userDropDown();
        return view('categories.index', compact('pagetitle', 'breadcrumbs', 'urls', 'userHtml', 'userRole'));
    }

    public function ajaxCategoryData(Request $request)
    {
        $userRole    = hasRole();
        if($userRole == 'Admin')
        {
            if($request->userId)
            {
                $categories = Category::where('user_id',$request->userId)->get();
            }
            else
            {
                $categories = array();
            }
        }
        else
        {
            $categories = Category::where('user_id',Auth::user()->id)->get();
        }
        return DataTables::of($categories)
            ->addColumn('image', function ($categories)
            {
                if(!empty($categories->image))
                {
                    $image = "<div class='btn-toolbar'>";
                    $image .= '<img class="avatar avatar-sm rounded-circle" src="'.$categories->image.'" alt="category image">';
                    $image .= "</div>";
                }
                else
                {
                    $image = "<div class='btn-toolbar'>";
                    $image .= "</div>";
                }
                return $image;
            })
            ->addColumn('published', function ($categories)
            {
                if($categories->published == 1)
                {
                    $published = "TRUE";
                }
                else
                {
                    $published = "FALSE";
                }
                return $published;
            })
            ->addColumn('created_at', function ($categories) 
            {
                return date('d-m-Y H:i:s', strtotime($categories->created_at));
            })
            ->rawColumns(['image','published', 'created_at'])
            ->make(TRUE);
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create(Request $request)
    {
        /* init settings */
        ini_set('memory_limit', '-1');
        set_time_limit(0);

        /* Get Categories Filters */
        $userRole    = hasRole();
        if($userRole == 'Admin' && !empty($request->userId))
        {
            $user = User::find($request->userId);
        }
        else
        {
            $user = Auth::user();
        }

        $categoriesFilter = CategoriesFilter::where('user_id',$user->id)->get();
        if(count($categoriesFilter) > 0 && !empty($categoriesFilter))
        {
            foreach ($categoriesFilter as $key => $filter) 
            {
                $collectionData = array();
                $categoryObj = Category::where('av_id', $filter->av_id)->where('user_id', $user->id)->first();
                if($categoryObj)
                {
                    continue;
                }
                else
                {
                    $arrayProducts = array();
                    $assigneItems = array();
                    $catProducts = getCatProducts($filter->av_id);
                    if($catProducts && isset($catProducts->products))
                    {
                        foreach ($catProducts->products as $key => $product) 
                        {
                            $productObj = Product::where('av_id', $product->id)->where('user_id', $user->id)->first();
                            if($productObj)
                            {
                                $arrayProducts[] = $productObj->wix_id;
                            }
                        }
                    }
                    $assigneItems['productIds'] = $arrayProducts;
                    $assigneItems = json_encode($assigneItems);
                

                    $categoriesFilterObj = CategoriesFilter::find($filter->id);
                    $categoriesFilterObj->products_count = count($arrayProducts);
                    $categoriesFilterObj->update();

                
                    $collectionData['collection'] = array('name' => $filter->name, 'media' => array('items' => array(array("url" => $filter->image))));
                    $collectionPost = json_encode($collectionData);

                    /* Create a Collection on wix store. */
                    $collectionCreateAPI = 'www.wixapis.com/stores/v1/collections';
                    $collectionResponse  = wixCall($user->id, $collectionCreateAPI, 'POST', $collectionPost);

                    if(!empty($collectionResponse) && isset($collectionResponse->collection))
                    {
                        /* Assign a Products newly created collection on wix store. */
                        $collectionAssignAPI = 'www.wixapis.com/stores/v1/collections/'.$collectionResponse->collection->id.'/productIds';
                        $collectionAssignResponse  = wixCall($user->id, $collectionAssignAPI, 'POST', $assigneItems);
                        
                        /* Create a Category on app */
                        $categoryObj = new Category;
                        $categoryObj->user_id = $user->id;
                        $categoryObj->av_id   = $filter->av_id;
                        $categoryObj->wix_id  = $collectionResponse->collection->id;
                        $categoryObj->name    = $filter->name;
                        $categoryObj->description        = $filter->description;
                        $categoryObj->image              =   $filter->image;
                        $categoryObj->parent_category_id =  $filter->parent_category_id;
                        $categoryObj->published          =   $filter->published;
                        $categoryObj->products_count     =  count($arrayProducts);
                        $categoryObj->save();
                    }
                }
            }
        }
        else
        {
            return response()->json(['status' => 'true', 'message' => "Currently Client category filters not selected."]);
        }
        return response()->json(['status' => 'true', 'message' => "Categories successfully synced on Wix Store."]);
    }

    public function categoriesUpdate(Request $request)
    {
        /* init settings */
        ini_set('memory_limit', '-1');
        set_time_limit(0);

        /* Get Categories Filters */
        $userRole    = hasRole();
        if($userRole == 'Admin' && !empty($request->userId))
        {
            $user = User::find($request->userId);
        }
        else
        {
            $user = Auth::user();
        }

        $categoriesFilter = CategoriesFilter::where('user_id',$user->id)->get();
        if(count($categoriesFilter) > 0 && !empty($categoriesFilter))
        {
            foreach ($categoriesFilter as $key => $filter) 
            {
                $collectionData = array();
                $categoryObj = Category::where('av_id', $filter->av_id)->where('user_id', $user->id)->first();
                if($categoryObj)
                {
                    $arrayProducts = array();
                    $assigneItems = array();
                    $catProducts = getCatProducts($filter->av_id);
                    if($catProducts && isset($catProducts->products))
                    {
                        foreach ($catProducts->products as $key => $product) 
                        {
                            $productObj = Product::where('av_id', $product->id)->where('user_id', $user->id)->first();
                            if($productObj)
                            {
                                $arrayProducts[] = $productObj->wix_id;
                            }
                        }
                    }
                    $assigneItems['productIds'] = $arrayProducts;
                    $assigneItems = json_encode($assigneItems);
                

                    $categoriesFilterObj = CategoriesFilter::find($filter->id);
                    $categoriesFilterObj->products_count = count($arrayProducts);
                    $categoriesFilterObj->update();

                
                    $collectionData['collection'] = array('name' => $filter->name, 'media' => array('items' => array(array("url" => $filter->image))));
                    $collectionPost = json_encode($collectionData);

                    /* Update a Collection on wix store. */
                    $collectionCreateAPI = 'www.wixapis.com/stores/v1/collections/'.$categoryObj->wix_id;
                    $collectionResponse  = wixCall($user->id, $collectionCreateAPI, 'POST', $collectionPost);

                    if(!empty($collectionResponse) && isset($collectionResponse->collection))
                    {
                        /* Assign a Products newly created collection on wix store. */
                        $collectionAssignAPI = 'www.wixapis.com/stores/v1/collections/'.$collectionResponse->collection->id.'/productIds';
                        $collectionAssignResponse  = wixCall($user->id, $collectionAssignAPI, 'POST', $assigneItems);
                        
                        /* Update a Category on app */
                        $categoryObj->name               = $filter->name;
                        $categoryObj->description        = $filter->description;
                        $categoryObj->image              = $filter->image;
                        $categoryObj->parent_category_id = $filter->parent_category_id;
                        $categoryObj->published          = $filter->published;
                        $categoryObj->products_count     = count($arrayProducts);
                        $categoryObj->update();
                    }
                }
            }
        }
        else
        {
            return response()->json(['status' => 'true', 'message' => "Currently Client category filters not selected."]);
        }
        return response()->json(['status' => 'true', 'message' => "Categories successfully Updated on Wix Store."]);
    }

    public function upload()
    {
        $pagetitle = "Upload Categories";
        $breadcrumbs = ["Dashboard","Categories", 'Upload Category'];
        $urls        = ['/home', 'categories/category-list', 'categories/category-upload' ];
        return view('categories.upload',compact('pagetitle', 'breadcrumbs', 'urls'));
    }


    public function uploader_summary()
    {
        $pagetitle = "Categories Create Summary";
        $breadcrumbs = ["Dashboard","Categories", 'Upload Summary'];
        $urls        = ['/home', 'categories/category-list', 'categories/category-create' ];
        $totalRec    = $this->errorSummary['total'];
        $saved       = $this->errorSummary['saved'];
        $update      = $this->errorSummary['update'];
        $skipped     = $this->errorSummary['skipped'];
        $error_detail = $this->errorSummary['error_detail'];
        return view('categories.summary',compact('pagetitle', 'breadcrumbs', 'urls', 'totalRec', 'saved', 'update', 'skipped', 'error_detail'));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function uploadData(Request $request)
    {
        $this->errorSummary['total'] =  0;
        $this->errorSummary['saved'] =  0;
        $this->errorSummary['update'] =  0;
        $this->errorSummary['skipped'] =  0;
        $this->errorSummary['error_detail'] =  "";
        $uploader_summary = $this->errorSummary;

        $rules = ['file' => 'required'];
        $validator = $this->validate($request, $rules);

        $userID = Auth::user()->id;
        $max_leads = 5000;
        if ($request->hasFile('file')) 
        {
            $file = $request->file('file');
            $columns = [
                            'name', 'description', 'image', 'published', 'parent_category_id'
                        ];
            if ($file->isValid()) 
            {
                $destinationPath = storage_path() . '/app/public/uploads/' . date('Ymd', time());
                $fullName = str_replace(" ", "", trim(strtolower($file->getClientOriginalName())));
                $extension = $file->getClientOriginalExtension();
                $onlyName = explode('.' . $extension, $fullName);
                $only_file_name = $onlyName[0] . "-" . date('Ymd-hi', time()) . "." . $extension;
                $file_name = $destinationPath . "/" . $only_file_name;
                $file->move($destinationPath, $file_name);

                if (!File::exists($file_name)) 
                {
                    return $this->errors(['message' => 'Error saving the file.', 'code' => 400]);
                }

                $data = Excel::toArray([], $file_name);
                if(count($data) > 0)
                {
                    $category_data = array();
                    
                    if (count($data[0]) <= $max_leads) 
                    {
                        $headers = $data[0][0];
                        if (count($headers) == count($columns)) 
                        {
                            $batch = date('Y-m-d H:i');
                            $skipLeadCount = 0;
                            $savedCount = 0;
                            $updateCount = 0;
                            $totalCount = 0;
                            $errors     = [];
                            $row_number = 1;
                            $updateWhere = 0;

                            foreach ($data[0] as $key => $row) 
                            {
                                if($key == 0)
                                {
                                    continue;
                                }

                                $columnExistCount =0 ;
                                $row_number++;
                                $totalCount++;
                                $recordHaveError = 0;
                                $uploaded_data = array("upload_by" => $userID);
                                $uploaded_data['vendor_id'] = $userID;
                                foreach ($columns as $column_key => $column_value) 
                                {
                                    if($column_value=="name")
                                    {
                                        $categoryName  = $row[$column_key];
                                        $categoryObj = Category::where('name',$categoryName)->first();
                                        if($categoryObj)
                                        {
                                            $updateWhere = $categoryObj->id;
                                            $uploaded_data['name'] = $categoryName;
                                            $uploaded_data['updated_at'] = date('Y-m-d H:i:s');
                                            $columnExistCount++;
                                        }
                                        else if($categoryName == "")
                                        {
                                            $recordHaveError = 1;
                                            $errors[]  = "Category name empty provided at row ".$row_number;
                                        }
                                        else
                                        {
                                            $uploaded_data['name'] = $categoryName;
                                            $uploaded_data['created_at'] = date('Y-m-d H:i:s');
                                            $columnExistCount++;
                                        }
                                    }
                                    else if($column_value=="description")
                                    {
                                        $categoryDesc  = $row[$column_key];
                                        if($categoryDesc!="")
                                        {
                                            $uploaded_data['description'] = $categoryDesc;
                                            $columnExistCount++;
                                        }
                                    }
                                    else if($column_value=="image")
                                    {
                                        $categoryimg  = $row[$column_key];
                                        if($categoryimg!="")
                                        {
                                            $uploaded_data['image'] = $categoryimg;
                                            $columnExistCount++;
                                        }
                                    }
                                    else if($column_value=="published")
                                    {
                                        $categoryPublished  = $row[$column_key];
                                        if($categoryPublished!="")
                                        {
                                            $uploaded_data['published'] = $categoryPublished;
                                            $columnExistCount++;
                                        }
                                    }
                                    else if($column_value=="parent_category_id")
                                    {
                                        $categoryParent  = $row[$column_key];
                                        if($categoryParent != "")
                                        {
                                            $categoryObj = Category::where('name',$categoryParent)->first();
                                            if($categoryObj)
                                            {
                                                $uploaded_data['parent_category_id'] = $categoryObj->id;
                                            }
                                            $columnExistCount++;
                                        }
                                        else if($categoryParent == 0)
                                        {
                                            $uploaded_data['parent_category_id'] = $categoryParent;
                                            $columnExistCount++;
                                        }
                                        else
                                        {
                                            $recordHaveError = 1;
                                            $errors[]  = "Category parent id empty provided at row ".$row_number;
                                        }
                                    }
                                }

                                if($columnExistCount > 3)
                                {
                                    if($recordHaveError==0)
                                    {
                                        try
                                        {
                                            if($updateWhere == 0)
                                            {
                                                $CategoryNew = Category::insert($uploaded_data);
                                            }
                                            else
                                            {
                                                $CategoryNew = DB::table('categories')
                                                                    ->where('id', $updateWhere)
                                                                    ->update($uploaded_data);
                                                $updateCount++;
                                            }
                                            $savedCount++;
                                        }
                                        catch (QueryException  $e)
                                        {
                                            $errors[]  = "Error while insert record at row ".$row_number;
                                            $skipLeadCount++;
                                        }
                                    }
                                }
                                else
                                {
                                    $errors[]  = "Column format is not according to the required format provided at row ".$row_number;
                                    $skipLeadCount++;
                                }
                                $uploaded_data  = array();
                            }

                            $this->errorSummary['total'] =  $totalCount;
                            $this->errorSummary['saved'] =  $savedCount;
                            $this->errorSummary['update'] =  $updateCount;
                            $this->errorSummary['skipped'] =  $skipLeadCount;
                            $this->errorSummary['error_detail'] =  implode("<br>",$errors);
                            return $this->uploader_summary();
                            //return view('uploader.uploader_summary', compact('page_title','total','totalSaved','skipped','errors'));
                        }
                        else 
                        {
                            return redirect('categories/category-create')->with('alert-error', 'Invalid File Format');
                        }
                    }
                    else 
                    {
                        return redirect('categories/category-create')->with('alert-error', 'Invalid File. Please Upload the file with at most {<strong>"' . $max_leads . '"</strong>} leads');
                    }
                };
            }
            else 
            {
                return redirect('categories/category-create')->with('alert-error', 'Invalid File Format');
            }
        }
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $rules = ['name' => 'required'];
        $validator = $this->validate($request, $rules);

        $userID = Auth::user()->id;
        $category = new Category;
        $category->vendor_id = $userID;
        $category->name = $request->name;
        $category->description = $request->description;
        if(isset($request->parent))
        {
            $category->parent_category_id = $request->parent;
        }
        else
        {
            $category->parent_category_id = 0;
        }
        // Category image
        if($request->hasFile('image'))
        {
            $image            = $request->file('image');
            $destination_path = 'public/categories-images';
            $filename = imageUpload($image,$destination_path);
            $category->image = "categories-images/".$filename;
        }
        if($category->save())
        {    
            return redirect('categories/category-list')->with('alert-success', 'Category Created Successfully');
        }
        else
        {
            return redirect('categories/category-create')->with('alert-error', $validator->errors());
        }
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        $category  = Category::find($id);
        $category_parent = '';
        if($category->parent_category_id > 0)
        {
            $category_parent  = Category::find($category->parent_category_id);
            $category_parent = $category_parent->name;
        }
        $pagetitle   = "View Category Details";
        $breadcrumbs = ["Dashboard","Categories", 'View Category Details'];
        $urls        = ['/home', 'categories/category-list', 'categories/category-show/'.$id ];
        return view('categories.show', compact('category', 'category_parent', 'pagetitle', 'breadcrumbs', 'urls'));
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        //
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        //
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy(Request $request)
    {
        /* init settings */
        ini_set('memory_limit', '-1');
        set_time_limit(0);

        /* Get Categories Filters */
        $userRole    = hasRole();
        if($userRole == 'Admin' && !empty($request->userId))
        {
            $user = User::find($request->userId);
        }
        else
        {
            $user = Auth::user();
        }

        $categories = Category::where('user_id',$user->id)->get();
        if(count($categories) > 0 && !empty($categories))
        {
            foreach ($categories as $key => $category) 
            {
                /* Delete a collection on wix store. */
                $collectionDeleteAPI = 'www.wixapis.com/stores/v1/collections/'.$category->wix_id;
                $collectionResponse  = wixCall($user->id, $collectionDeleteAPI, 'DELETE');
                $category->delete();
            }
        }
        else
        {
            return response()->json(['status' => 'true', 'message' => "Currently Client category filters not selected."]);
        }
        return response()->json(['status' => 'true', 'message' => "Categories successfully Removed on Wix Store."]);
    }
}
