<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\CategoriesFilter;
use Illuminate\Support\Facades\Validator;
use DB;
use Storage;
use Auth;
use Excel;
use File;
use App\User;
use Yajra\DataTables\DataTables;

class CategoryFilterController extends Controller
{

    function __construct()
    {
        $this->middleware('auth');
        $this->middleware('permission:filter-list|filter-create', ['only' => ['index','store']]);
        $this->middleware('permission:filter-create', ['only' => ['create','store']]);
        $this->middleware('permission:filter-ajax-data', ['only' => ['ajaxCategoryFilterData']]);
    }
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $pagetitle   = "Categories Filter";
        $breadcrumbs = ["Dashboard", "Categories Filter"];
        $urls        = ['/home', 'categories-filter'];
        $userRole    = hasRole();
        $userHtml    = userDropDown();
        return view('categories_filter.index', compact('pagetitle', 'breadcrumbs', 'urls', 'userHtml', 'userRole'));
    }

    public function ajaxCategoryFilterData(Request $request)
    {
        $userRole    = hasRole();
        if($userRole == 'Admin')
        {
            if($request->userId)
            {
                $categoriesFilter = CategoriesFilter::where('user_id',$request->userId)->get();
            }
            else
            {
                $categoriesFilter = array();
            }
        }
        else
        {
            $categoriesFilter = CategoriesFilter::where('user_id',Auth::user()->id)->get();
            //$categoriesFilter = CategoriesFilter::all();
        }
        return DataTables::of($categoriesFilter)
            ->addColumn('image', function ($categoriesFilter)
            {
                if(!empty($categoriesFilter->image))
                {
                    $image = "<div class='btn-toolbar'>";
                    $image .= '<img class="avatar avatar-sm rounded-circle" src="'.$categoriesFilter->image.'" alt="categories Filter image">';
                    $image .= "</div>";
                }
                else
                {
                    $image = "<div class='btn-toolbar'>";
                    $image .= "</div>";
                }
                return $image;
            })
            ->addColumn('published', function ($categoriesFilter)
            {
                if($categoriesFilter->published == 1)
                {
                    $published = "TRUE";
                }
                else
                {
                    $published = "FALSE";
                }
                return $published;
            })
            ->addColumn('actions', function ($categoriesFilter)
            {
                $actions = "<div class='btn-toolbar'>";
                $actions .= '<a class="btn btn-outline-primary btn-icon-only" href="' . url("#", $categoriesFilter->id) . '" data-toggle="tooltip" title="Category Sync"><i class="fa fa-sync"></i></a>';
                $actions .= '<a class="btn btn-outline-info btn-icon-only" href="' . url("#", $categoriesFilter->id) . '" data-toggle="tooltip" title="Products Sync"><i class="fa fa-sync"></i></a>';
                $actions .= '<a class="btn btn-outline-success btn-icon-only" href="' . url("#", $categoriesFilter->id) . '" data-toggle="tooltip" title="Products View"><i class="fa fa-eye"></i></a>';
                $actions .= '<a class="btn btn-outline-danger btn-icon-only" href="' . url("#", $categoriesFilter->id) . '" data-toggle="tooltip" title="Products Remove"><i class="fa fa-trash"></i></a>';
                $actions .= "</div>";
                return $actions;
            })
            ->addColumn('created_at', function ($categoriesFilter) 
            {
                return date('d-m-Y H:i:s', strtotime($categoriesFilter->created_at));
            })
            ->rawColumns(['image','published','actions'])
            ->make(TRUE);
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        //
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        if(isset($request->cat_filter) && count($request->cat_filter) > 0)
        {
            $categoriesFilters = CategoriesFilter::where('user_id',Auth::user()->id)->get();
            if($categoriesFilters)
            {
                foreach ($categoriesFilters as $key => $categoriesFilter) 
                {
                    $categoriesFilter->delete();
                }
            }

            foreach ($request->cat_filter as $key => $value) 
            {
                $categoriesFilter = new CategoriesFilter;
                $filterValue = explode(",",$value);
                $categoriesFilter->user_id              = Auth::user()->id;
                $categoriesFilter->av_id                = $filterValue[0];
                $categoriesFilter->name                 = $filterValue[1];
                $categoriesFilter->published            = $filterValue[2];
                $categoriesFilter->parent_category_id   = $filterValue[3];
                $categoriesFilter->description          = $filterValue[4];
                $categoriesFilter->image                = $filterValue[5];
                $categoriesFilter->save();
            }
            return redirect('store-filters/store-filter-list')->with('alert-success', 'Category Filters Updated Successfully');
        }
        else
        {
            return redirect('store-filters/store-filter-list')->with('alert-error', 'Please select at least one category');
        }
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        //
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        //
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        //
    }
}
