<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use Illuminate\Support\Facades\Validator;
use DB;
use Storage;
use Auth;
use App\User;
use App\CategoriesFilter;
use App\Product;
use App\Variant;
use App\ProductLog;
use App\ProductUpdateLog;
use Yajra\DataTables\DataTables;

class ProductsController extends Controller
{
    var $errorSummary = [];
    function __construct()
    {
        $this->middleware('auth');
        $this->middleware('permission:product-list|product-create|product-upload|product-edit|product-delete', ['only' => ['index','store']]);
        $this->middleware('permission:product-create', ['only' => ['create','store']]);
        $this->middleware('permission:product-upload', ['only' => ['upload']]);
        $this->middleware('permission:product-upload-csv', ['only' => ['uploadData']]);
        $this->middleware('permission:product-update', ['only' => ['productsUpdate']]);
        $this->middleware('permission:product-delete', ['only' => ['productsRemove']]);
        $this->middleware('permission:product-show', ['only' => ['show']]);
        $this->middleware('permission:product-ajax-data', ['only' => ['ajaxProductsData']]);
    }
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $pagetitle   = "Products";
        $breadcrumbs = ["Dashboard", "Products"];
        $urls        = ['/home', 'products/product-list'];
        $userRole    = hasRole();
        $userHtml    = userDropDown();
        return view('products.index', compact('pagetitle', 'breadcrumbs', 'urls', 'userHtml', 'userRole'));
    }

    public function ajaxProductsData(Request $request)
    {
        $userRole    = hasRole();
        if($userRole == 'Admin')
        {
            if($request->userId)
            {
                $products = Product::where('user_id',$request->userId)->get();
            }
            else
            {
                $products = array();
            }
        }
        else
        {
            $products = Product::where('user_id',Auth::user()->id)->get();
        }
        return DataTables::of($products)
            ->addColumn('image', function ($products)
            {
                if(!empty($products->image))
                {
                    $image = "<div class='btn-toolbar'>";
                    $image .= '<img class="avatar avatar-sm rounded-circle" src="'.$products->image.'" alt="Products image">';
                    $image .= "</div>";
                }
                else
                {
                    $image = "<div class='btn-toolbar'>";
                    $image .= "</div>";
                }
                return $image;
            })
            ->addColumn('updated_at', function ($products) 
            {
                return date('d-m-Y H:i:s', strtotime($products->updated_at));
            })
            ->rawColumns(['image', 'updated_at'])
            ->make(TRUE);
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create(Request $request)
    {
        /* init settings */
        ini_set('memory_limit', '-1');
        set_time_limit(0);

        /* Get user filters */
        $userRole    = hasRole();
        if($userRole == 'Admin' && !empty($request->userId))
        {
            $user = User::find($request->userId);
        }
        else
        {
            $user = Auth::user();
        }

        $price_key      = 0;
        $quantity_key   = 0;
        $less_price     = 0;
        $greater_price  = 0;

        if (isset($user->filters) && count($user->filters) > 0)
        {
            foreach ($user->filters as $filter)
            {
                if($filter->key == 'price_key')
                {
                    $price_key = $filter->value;
                }
                else if($filter->key == 'quantity_key')
                {
                    $quantity_key = $filter->value;
                }
                else if($filter->key == 'less_price')
                {
                    $less_price = $filter->value;
                }
                else if($filter->key == 'greater_price')
                {
                    $greater_price = $filter->value;
                }
            }
        }
        else
        {
            return response()->json(['status' => 'true', 'message' => "Currently Client filters not selected."]);
        }

        /* Get Categories Filters */
        $categoriesFilter = CategoriesFilter::where('user_id',$user->id)->get();
        if(count($categoriesFilter) > 0 && !empty($categoriesFilter))
        {
            foreach ($categoriesFilter as $key => $filter) 
            {
                $catProducts = getCatProducts($filter->av_id);
                if($catProducts && isset($catProducts->products))
                {
                    foreach ($catProducts->products as $key => $product) 
                    {
                        $productObj = Product::where('av_id', $product->id)->where('user_id', $user->id)->first();
                        if($productObj)
                        {
                            continue;
                        }
                        else
                        {
                            $productData = array();
                            $desc        = '';
                            if($product->tierprice[0]->price <= $less_price && $product->tierprice[0]->price >= $greater_price && $product->stock_quantity >= $quantity_key)
                            {
                                $new_price = $product->tierprice[0]->price * $price_key;
                                $desc      = '<p>';
                                // $desc     .= 'JewelleryType:'.str_replace("\n", '', $product->JewelleryType);
                                // $desc     .= "<br>";

                                // if($product->RingType)
                                // {
                                //     $desc .= 'RingType:'.$product->RingType;
                                //     $desc .= "<br>";
                                // }
                                // if($product->RingSize)
                                // {
                                //     $desc .= 'RingSize:'.$product->RingSize;
                                //     $desc .= "<br>";
                                // }
                            
                                foreach ($product->specificationattributes as $key => $value) 
                                {
                                    $desc .= $value->specification_attribute_name.': '.$value->specification_attribute_value;
                                    $desc     .= "<br>";
                                }
                                $desc     .= "</p>";

                                if(count($product->attributes) > 0 && isset($product->JewelleryType) && strtolower($product->JewelleryType) == 'ring')
                                {
                                    $ringSize = array();
                                    foreach ($product->attributes[0]->attribute_values as $key => $attribute_value) 
                                    {
                                        $ringSize[] = array("value" => $attribute_value->name, "description" => $attribute_value->name); 
                                    }

                                    $productData["product"] = array("name" => $product->name, 
                                                                "productType" => "physical",
                                                                "priceData"   => array("price" => $new_price),
                                                                "stock"       => array("trackInventory" => true, "quantity" => $product->stock_quantity, "inStock" => true),
                                                                "description" => $desc,
                                                                "sku"         => $product->sku,
                                                                "visible"     => true,
                                                                "weight"      => $product->weight,
                                                                "manageVariants" => true,
                                                                "productOptions" => array(array("name" => "Size", "choices" => $ringSize))
                                                            );
                                }
                                else
                                {
                                    $productData["product"] = array("name" => $product->name, 
                                                                "productType" => "physical",
                                                                "priceData"   => array("price" => $new_price),
                                                                "stock"       => array("trackInventory" => true, "quantity" => $product->stock_quantity, "inStock" => true),
                                                                "description" => $desc,
                                                                "sku"         => $product->sku,
                                                                "visible"     => true,
                                                                "weight"      => $product->weight
                                                            );
                                }

                                $postData = json_encode($productData);

                                //create a product log on every product.
                                $productLog = new ProductLog;
                                $productLog->user_id = $user->id;
                                $productLog->av_product_id  = $product->id;
                                $productLog->category_id    = $filter->av_id;
                                $productLog->name           = $product->name;
                                $productLog->price          = $new_price;
                                $productLog->sku            = $product->sku;
                                $productLog->stock_quantity = $product->stock_quantity;
                                $productLog->action         = 'Sync product';
                                $productLog->save();

                                /* Create a product on wix store. */
                                $productCreateAPI = 'www.wixapis.com/stores/v1/products';
                                $productResponse  = wixCall($user->id, $productCreateAPI, 'POST', $postData);

                                /*Create a Product Media on wix store. */
                                if(!empty($productResponse) && isset($productResponse->product))
                                {
                                    $imageArray = array();
                                    foreach ($product->images as $key => $image) 
                                    {
                                        $imageArray[] = array("url" => $image->src);
                                    }
                                    $mediaData = array();
                                    $mediaData["media"] = $imageArray;
                                    $mediaData = json_encode($mediaData);

                                    $mediaCreateAPI = 'www.wixapis.com/stores/v1/products/'.$productResponse->product->id.'/media';
                                    $mediaResponse  = wixCall($user->id, $mediaCreateAPI, 'POST', $mediaData);

                                    $productObj = new Product;
                                    $productObj->user_id = $user->id;
                                    $productObj->av_id   = $product->id;
                                    $productObj->wix_id  = $productResponse->product->id;
                                    $productObj->inventoryItemId = $productResponse->product->inventoryItemId;
                                    $productObj->category_id     = $filter->av_id;
                                    $productObj->name            = $productResponse->product->name;
                                    $productObj->slug            = $productResponse->product->slug;
                                    $productObj->av_price        = $product->tierprice[0]->price;
                                    $productObj->wix_price       = $new_price;
                                    $productObj->sku             = $product->sku;
                                    $productObj->description     = $productResponse->product->description;
                                    $productObj->weight          = $product->weight;
                                    $productObj->stock_quantity  = $product->stock_quantity;
                                    $productObj->image           = $product->images[0]->src;
                                    $productObj->save();

                                    if(count($productResponse->product->variants) > 1)
                                    {
                                        foreach ($productResponse->product->variants as $key => $variant) 
                                        {
                                            $variantObj = new Variant;
                                            $variantObj->product_id =  $productObj->id;
                                            $variantObj->wix_id     =  $variant->id;
                                            $variantObj->wix_price  =  $new_price;
                                            $variantObj->size       =  $variant->choices->Size;
                                            $variantObj->save();
                                        }
                                    }
                                }
                            }
                        }
                    }
                }
            }
        }
        else
        {
            return response()->json(['status' => 'true', 'message' => "Currently Client category filters not selected."]);
        }
        return response()->json(['status' => 'true', 'message' => "Products successfully synced on Wix Store."]);
    }

    public function productsUpdate(Request $request)
    {
        /* init settings */
        ini_set('memory_limit', '-1');
        set_time_limit(0);

        /* Get user filters */
        $userRole    = hasRole();
        if($userRole == 'Admin' && !empty($request->userId))
        {
            $user = User::find($request->userId);
        }
        else
        {
            $user = Auth::user();
        }

        $price_key      = 0;
        $quantity_key   = 0;
        $less_price     = 0;
        $greater_price  = 0;

        if (isset($user->filters) && count($user->filters) > 0)
        {
            foreach ($user->filters as $filter)
            {
                if($filter->key == 'price_key')
                {
                    $price_key = $filter->value;
                }
                else if($filter->key == 'quantity_key')
                {
                    $quantity_key = $filter->value;
                }
                else if($filter->key == 'less_price')
                {
                    $less_price = $filter->value;
                }
                else if($filter->key == 'greater_price')
                {
                    $greater_price = $filter->value;
                }
            }
        }
        else
        {
            return response()->json(['status' => 'true', 'message' => "Currently Client filters not selected."]);
        }

        /* Get Products Update */
        $getProductsUpdate = getProductsUpdate();
        if($getProductsUpdate && isset($getProductsUpdate->products))
        {
            foreach ($getProductsUpdate->products as $key => $product) 
            {
                $productObj = Product::where('av_id', $product->id)->where('user_id', $user->id)->first();
                if($productObj && !empty($productObj))
                {
                    if($product->stock_quantity < $quantity_key)
                    {
                        /* Delete a product on wix store. */
                        $productDeleteAPI = 'www.wixapis.com/stores/v1/products/'.$productObj->wix_id;
                        $productResponse  = wixCall($user->id, $productDeleteAPI, 'DELETE');

                        if(true)
                        {
                            $variants = Variant::where('product_id', $productObj->id)->get();

                            /* Delete product Variant if avaliable */
                            if($variants)
                            {
                                foreach ($variants as $key => $variantObj) 
                                {
                                    $variantObj->delete();
                                }
                            }

                            $productUpdateLog = new ProductUpdateLog;
                            $productUpdateLog->user_id = $user->id;
                            $productUpdateLog->product_id = $productObj->id;
                            $productUpdateLog->av_product_id = $productObj->av_id;
                            $productUpdateLog->category_id = $productObj->category_id;
                            $productUpdateLog->name = $productObj->name;
                            $productUpdateLog->price = $productObj->wix_price;
                            $productUpdateLog->sku = $productObj->sku;
                            $productUpdateLog->stock_quantity = $product->stock_quantity;
                            $productUpdateLog->action = 'Deleted Product';
                            $productUpdateLog->save();

                            /* Delete product on app */
                            $productObj->delete();
                        }
                    }
                    else
                    {
                        $productData = array();
                        $desc        = '';
                        if($product->tierprice[0]->price <= $less_price && $product->tierprice[0]->price >= $greater_price && $product->stock_quantity >= $quantity_key)
                        {
                            $new_price = $product->tierprice[0]->price * $price_key;
                            $desc      = '<p>';
                            // $desc     .= 'JewelleryType:'.str_replace("\n", '', $product->JewelleryType);
                            // $desc     .= "<br>";
                            // if($product->RingType)
                            // {
                            //     $desc .= 'RingType:'.$product->RingType;
                            //     $desc .= "<br>";
                            // }
                            // if($product->RingSize)
                            // {
                            //     $desc .= 'RingSize:'.$product->RingSize;
                            //     $desc .= "<br>";
                            // }
                        
                            foreach ($product->specificationattributes as $key => $value) 
                            {
                                $desc .= $value->specification_attribute_name.': '.$value->specification_attribute_value;
                                $desc     .= "<br>";
                            }
                            $desc     .= "</p>";
                            if(count($product->attributes) > 0 && isset($product->JewelleryType) && strtolower($product->JewelleryType) == 'ring')
                            {
                                $ringSize = array();
                                foreach ($product->attributes[0]->attribute_values as $key => $attribute_value) 
                                {
                                    $ringSize[] = array("value" => $attribute_value->name, "description" => $attribute_value->name); 
                                }
                                $productData["product"] = array("name" => $product->name, 
                                                            "productType" => "physical",
                                                            "priceData"   => array("price" => $new_price),
                                                            "stock"       => array("trackInventory" => true, "quantity" => $product->stock_quantity, "inStock" => true),
                                                            "description" => $desc,
                                                            "sku"         => $product->sku,
                                                            "visible"     => true,
                                                            "weight"      => $product->weight,
                                                            "manageVariants" => true,
                                                            "productOptions" => array(array("name" => "Size", "choices" => $ringSize))
                                                        );
                            }
                            else
                            {
                                $productData["product"] = array("name" => $product->name, 
                                                            "productType" => "physical",
                                                            "priceData"   => array("price" => $new_price),
                                                            "stock"       => array("trackInventory" => true, "quantity" => $product->stock_quantity, "inStock" => true),
                                                            "description" => $desc,
                                                            "sku"         => $product->sku,
                                                            "visible"     => true,
                                                            "weight"      => $product->weight
                                                        );
                            }
                            $postData = json_encode($productData);

                            //create a product log on every product.
                            $productUpdateLog = new ProductUpdateLog;
                            $productUpdateLog->user_id = $user->id;
                            $productUpdateLog->product_id = $productObj->id;
                            $productUpdateLog->av_product_id = $productObj->av_id;
                            $productUpdateLog->category_id = $productObj->category_id;
                            $productUpdateLog->name = $product->name;
                            $productUpdateLog->price = $new_price;
                            $productUpdateLog->sku = $product->sku;
                            $productUpdateLog->stock_quantity = $product->stock_quantity;
                            $productUpdateLog->action = 'Updated Product';
                            $productUpdateLog->save();

                            /* Create a product on wix store. */
                            $productCreateAPI = 'www.wixapis.com/stores/v1/products/'.$productObj->wix_id;
                            $productResponse  = wixCall($user->id, $productCreateAPI, 'POST', $postData);

                            /*Create a Product Media on wix store. */
                            if(!empty($productResponse) && isset($productResponse->product))
                            {
                                $productObj->name            = $productResponse->product->name;
                                $productObj->slug            = $productResponse->product->slug;
                                $productObj->av_price        = $product->tierprice[0]->price;
                                $productObj->wix_price       = $new_price;
                                $productObj->sku             = $product->sku;
                                $productObj->description     = $productResponse->product->description;
                                $productObj->weight          = $product->weight;
                                $productObj->stock_quantity  = $product->stock_quantity;
                                $productObj->image           = $product->images[0]->src;
                                $productObj->update();

                                if(count($productResponse->product->variants) > 1)
                                {
                                    $variants = Variant::where('product_id', $productObj->id)->get();

                                    /* Delete product Variant if avaliable */
                                    if($variants)
                                    {
                                        foreach ($variants as $key => $variantObj) 
                                        {
                                            $variantObj->delete();
                                        }
                                    }

                                    foreach ($productResponse->product->variants as $key => $variant) 
                                    {
                                        $variantObj = new Variant;
                                        $variantObj->product_id =  $productObj->id;
                                        $variantObj->wix_id     =  $variant->id;
                                        $variantObj->wix_price  =  $new_price;
                                        $variantObj->size       =  $variant->choices->Size;
                                        $variantObj->save();
                                    }
                                }
                            }
                        }
                    }
                }
            }
        }
        return response()->json(['status' => 'true', 'message' => "Products successfully Updated on Wix Store."]);
    }

    public function productsRemove(Request $request)
    {
        /* init settings */
        ini_set('memory_limit', '-1');
        set_time_limit(0);

        /* Get user filters */
        $userRole    = hasRole();
        if($userRole == 'Admin' && !empty($request->userId))
        {
            $user = User::find($request->userId);
        }
        else
        {
            $user = Auth::user();
        }
        
        $products = Product::where('user_id', $user->id)->get();
        if($products)
        {
            foreach ($products as $key => $productObj) 
            {
                /* Delete a product on wix store. */
                $productDeleteAPI = 'www.wixapis.com/stores/v1/products/'.$productObj->wix_id;
                $productResponse  = wixCall($user->id, $productDeleteAPI, 'DELETE');
                if(true)
                {
                    $variants = Variant::where('product_id', $productObj->id)->get();
                    /* Delete product Variant if avaliable */
                    if($variants)
                    {
                        foreach ($variants as $key => $variantObj) 
                        {
                            $variantObj->delete();
                        }
                    }

                    $productUpdateLog = new ProductUpdateLog;
                    $productUpdateLog->user_id = $user->id;
                    $productUpdateLog->product_id = $productObj->id;
                    $productUpdateLog->av_product_id = $productObj->av_id;
                    $productUpdateLog->category_id = $productObj->category_id;
                    $productUpdateLog->name = $productObj->name;
                    $productUpdateLog->price = $productObj->wix_price;
                    $productUpdateLog->sku = $productObj->sku;
                    $productUpdateLog->stock_quantity = $productObj->stock_quantity;
                    $productUpdateLog->action = 'Deleted Product';
                    $productUpdateLog->save();
                    /* Delete product on app */
                    $productObj->delete();
                }
            }
        }
        return response()->json(['status' => 'true', 'message' => "Products successfully Deleted on Wix Store and also app."]);
    }

    public function upload()
    {
        $pagetitle = "Upload Products";
        $breadcrumbs = ["Dashboard","Products", 'Upload Products'];
        $urls        = ['/home', 'products/product-list', 'products/product-upload' ];
        return view('products.upload',compact('pagetitle', 'breadcrumbs', 'urls'));
    }

    public function uploader_summary()
    {
        $pagetitle = "Products Create Summary";
        $breadcrumbs = ["Dashboard","Products", 'Upload Summary'];
        $urls        = ['/home', 'products/product-list', 'products/product-create' ];
        $totalRec    = $this->errorSummary['total'];
        $saved       = $this->errorSummary['saved'];
        $update      = $this->errorSummary['update'];
        $skipped     = $this->errorSummary['skipped'];
        $error_detail = $this->errorSummary['error_detail'];
        return view('products.summary',compact('pagetitle', 'breadcrumbs', 'urls', 'totalRec', 'saved', 'update', 'skipped', 'error_detail'));
    }

    public function uploadData(Request $request)
    {
        $this->errorSummary['total'] =  0;
        $this->errorSummary['saved'] =  0;
        $this->errorSummary['update'] =  0;
        $this->errorSummary['skipped'] =  0;
        $this->errorSummary['error_detail'] =  "";
        $uploader_summary = $this->errorSummary;
        return $this->uploader_summary();

        $rules = ['file' => 'required'];
        $validator = $this->validate($request, $rules);

        $userID = Auth::user()->id;
        $max_leads = 5000;
        if ($request->hasFile('file')) 
        {
            $file = $request->file('file');
            $columns = [
                            'name', 'description', 'image', 'published', 'parent_category_id'
                        ];
            if ($file->isValid()) 
            {
                $destinationPath = storage_path() . '/app/public/uploads/' . date('Ymd', time());
                $fullName = str_replace(" ", "", trim(strtolower($file->getClientOriginalName())));
                $extension = $file->getClientOriginalExtension();
                $onlyName = explode('.' . $extension, $fullName);
                $only_file_name = $onlyName[0] . "-" . date('Ymd-hi', time()) . "." . $extension;
                $file_name = $destinationPath . "/" . $only_file_name;
                $file->move($destinationPath, $file_name);

                if (!File::exists($file_name)) 
                {
                    return $this->errors(['message' => 'Error saving the file.', 'code' => 400]);
                }

                $data = Excel::toArray([], $file_name);
                if(count($data) > 0)
                {
                    $category_data = array();
                    
                    if (count($data[0]) <= $max_leads) 
                    {
                        $headers = $data[0][0];
                        if (count($headers) == count($columns)) 
                        {
                            $batch = date('Y-m-d H:i');
                            $skipLeadCount = 0;
                            $savedCount = 0;
                            $updateCount = 0;
                            $totalCount = 0;
                            $errors     = [];
                            $row_number = 1;
                            $updateWhere = 0;

                            foreach ($data[0] as $key => $row) 
                            {
                                if($key == 0)
                                {
                                    continue;
                                }

                                $columnExistCount =0 ;
                                $row_number++;
                                $totalCount++;
                                $recordHaveError = 0;
                                $uploaded_data = array("upload_by" => $userID);
                                $uploaded_data['vendor_id'] = $userID;
                                foreach ($columns as $column_key => $column_value) 
                                {
                                    if($column_value=="name")
                                    {
                                        $categoryName  = $row[$column_key];
                                        $categoryObj = Category::where('name',$categoryName)->first();
                                        if($categoryObj)
                                        {
                                            $updateWhere = $categoryObj->id;
                                            $uploaded_data['name'] = $categoryName;
                                            $uploaded_data['updated_at'] = date('Y-m-d H:i:s');
                                            $columnExistCount++;
                                        }
                                        else if($categoryName == "")
                                        {
                                            $recordHaveError = 1;
                                            $errors[]  = "Category name empty provided at row ".$row_number;
                                        }
                                        else
                                        {
                                            $uploaded_data['name'] = $categoryName;
                                            $uploaded_data['created_at'] = date('Y-m-d H:i:s');
                                            $columnExistCount++;
                                        }
                                    }
                                    else if($column_value=="description")
                                    {
                                        $categoryDesc  = $row[$column_key];
                                        if($categoryDesc!="")
                                        {
                                            $uploaded_data['description'] = $categoryDesc;
                                            $columnExistCount++;
                                        }
                                    }
                                    else if($column_value=="image")
                                    {
                                        $categoryimg  = $row[$column_key];
                                        if($categoryimg!="")
                                        {
                                            $uploaded_data['image'] = $categoryimg;
                                            $columnExistCount++;
                                        }
                                    }
                                    else if($column_value=="published")
                                    {
                                        $categoryPublished  = $row[$column_key];
                                        if($categoryPublished!="")
                                        {
                                            $uploaded_data['published'] = $categoryPublished;
                                            $columnExistCount++;
                                        }
                                    }
                                    else if($column_value=="parent_category_id")
                                    {
                                        $categoryParent  = $row[$column_key];
                                        if($categoryParent != "")
                                        {
                                            $categoryObj = Category::where('name',$categoryParent)->first();
                                            if($categoryObj)
                                            {
                                                $uploaded_data['parent_category_id'] = $categoryObj->id;
                                            }
                                            $columnExistCount++;
                                        }
                                        else if($categoryParent == 0)
                                        {
                                            $uploaded_data['parent_category_id'] = $categoryParent;
                                            $columnExistCount++;
                                        }
                                        else
                                        {
                                            $recordHaveError = 1;
                                            $errors[]  = "Category parent id empty provided at row ".$row_number;
                                        }
                                    }
                                }

                                if($columnExistCount > 3)
                                {
                                    if($recordHaveError==0)
                                    {
                                        try
                                        {
                                            if($updateWhere == 0)
                                            {
                                                $CategoryNew = Category::insert($uploaded_data);
                                            }
                                            else
                                            {
                                                $CategoryNew = DB::table('categories')
                                                                    ->where('id', $updateWhere)
                                                                    ->update($uploaded_data);
                                                $updateCount++;
                                            }
                                            $savedCount++;
                                        }
                                        catch (QueryException  $e)
                                        {
                                            $errors[]  = "Error while insert record at row ".$row_number;
                                            $skipLeadCount++;
                                        }
                                    }
                                }
                                else
                                {
                                    $errors[]  = "Column format is not according to the required format provided at row ".$row_number;
                                    $skipLeadCount++;
                                }
                                $uploaded_data  = array();
                            }

                            $this->errorSummary['total'] =  $totalCount;
                            $this->errorSummary['saved'] =  $savedCount;
                            $this->errorSummary['update'] =  $updateCount;
                            $this->errorSummary['skipped'] =  $skipLeadCount;
                            $this->errorSummary['error_detail'] =  implode("<br>",$errors);
                            return $this->uploader_summary();
                            //return view('uploader.uploader_summary', compact('page_title','total','totalSaved','skipped','errors'));
                        }
                        else 
                        {
                            return redirect('categories/category-create')->with('alert-error', 'Invalid File Format');
                        }
                    }
                    else 
                    {
                        return redirect('categories/category-create')->with('alert-error', 'Invalid File. Please Upload the file with at most {<strong>"' . $max_leads . '"</strong>} leads');
                    }
                };
            }
            else 
            {
                return redirect('categories/category-create')->with('alert-error', 'Invalid File Format');
            }
        }
    }
    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        return redirect('products/product-list')->with('alert-success', 'Product Created Successfully');
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        //
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        //
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        //
    }
}
