<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\Setting;
use Illuminate\Support\Facades\Validator;
use DB;
use Storage;
use Yajra\DataTables\DataTables;

class SettingsController extends Controller
{
    function __construct()
    {
        $this->middleware('auth');
        $this->middleware('permission:setting-list|setting-create|setting-edit|setting-delete', ['only' => ['index','store']]);
        $this->middleware('permission:setting-create', ['only' => ['create','store']]);
        $this->middleware('permission:setting-edit', ['only' => ['edit','update']]);
        $this->middleware('permission:setting-delete', ['only' => ['destroy']]);
        $this->middleware('permission:setting-show', ['only' => ['show']]);
        $this->middleware('permission:setting-ajax-data', ['only' => ['ajaxSettingData']]);
    }
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $settings    = Setting::all();
        $pagetitle   = "Settings";
        $breadcrumbs = ["Dashboard", "Settings"];
        $urls        = ['/home', 'settings/setting-list'];
        return view('settings.index', compact('settings','pagetitle', 'breadcrumbs', 'urls'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        //
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $rules = [
            'name' => 'required|string|max:150',
            'key' => 'required|max:150|unique:settings,key',
            'type' => 'required|string',
            'group' => 'required|string'
        ];

        $validator = $this->validate($request, $rules);
        
        $setting_order = Setting::count();
        $setting = new Setting;
        $setting->name  = $request->name;
        $setting->key   = $request->group.'.'.$request->key;
        $setting->type  = $request->type;
        $setting->order = $setting_order+1;
        $setting->group = ucwords($request->group);
        if($setting->save())
        {    
            return redirect('settings/setting-list')->with('alert-success', 'Setting Created Successfully');
        }
        else
        {
            return redirect('settings-management/setting-list')->with('alert-error', $validator->errors());
        }
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        //
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        $setting = Setting::find($id);
        if($setting)
        {
            $setting->value  = $request->value;
            $setting->group = ucwords($request->group);
            // Update image file
            if($request->hasFile('image'))
            {
                $image            = $request->file('image');
                $destination_path = 'public/settings';
                $filename = imageUpload($image,$destination_path);
                $setting->value = "settings/".$filename;
            }
            if($setting->save())
            {    
                return redirect('settings/setting-list')->with('alert-success', 'Setting Updated Successfully');
            }
            else
            {
                return redirect('settings-management/setting-list')->with('alert-error', $validator->errors());
            }
        }
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        $setting = Setting::find($id);
        if($setting->type == 'image')
        {
            $file = explode('/',$setting->value);
            $storage = 'app/public/settings/'.$file[1];
            $storage_files = storage_path($storage);
            unlink($storage_files);
        }
        if($setting->delete())
        {    
            return redirect('settings/setting-list')->with('alert-success', 'Setting Deleted Successfully');
        }
    }
}
