<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\StoreFilter;
use App\User;
use Illuminate\Support\Facades\Validator;
use DB;
use Storage;
use Auth;
use Yajra\DataTables\DataTables;

class StoreFiltersController extends Controller
{
    function __construct()
    {
        $this->middleware('auth');
        $this->middleware('permission:store-filter-list|store-filter-create|store-filter-edit|store-filter-delete', ['only' => ['index','store']]);
        $this->middleware('permission:store-filter-store', ['only' => ['create','store']]);
        $this->middleware('permission:store-filter-edit', ['only' => ['edit','update']]);
        $this->middleware('permission:store-filter-delete', ['only' => ['destroy']]);
        $this->middleware('permission:store-filter-show', ['only' => ['show']]);
        $this->middleware('permission:store-filter-ajax-data', ['only' => ['ajaxFiltersData']]);
    }
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $pagetitle   = "Store Filters";
        $breadcrumbs = ["Dashboard", "Store Filters"];
        $urls        = ['/home', 'store-filters/store-filter-list'];
        $getCategories  = getCategories();
        //$getCategories  = array();
        return view('storeFilters.index', compact('pagetitle', 'breadcrumbs', 'urls', 'getCategories'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        //
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $rules = [
            'filters' => 'required',
        ];

        $validator = $this->validate($request, $rules);
        $user = Auth::user();
        if(count($user->filters) > 0)
        {
            foreach ($user->filters as $key => $filter) 
            {
                $filter->delete();
            }
        }
        
        foreach ($request->filters as $key => $filter) 
        {
            $nameArray = explode('_', $key);
            $name = $nameArray[0].' '.$nameArray[1];
            $name = ucwords($name);
            $storeFilter = new StoreFilter;
            $storeFilter->user_id = $user->id;
            $storeFilter->key = $key;
            $storeFilter->name = $name;
            $storeFilter->value = $filter;
            $storeFilter->save();
        }

        return redirect('store-filters/store-filter-list')->with('alert-success', 'Filters Settings Updated Successfully');
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        //
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        //
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        //
    }
}
