@extends('layouts.auth.master')

@section('page_css')
@endsection

@section('content')
<div class="card bg-secondary border-0 mb-0">
    <div class="card-body px-lg-5 py-lg-3">
        <div class="text-center text-muted mb-4">
            <small>Sign in with credentials</small>
        </div>
        @if (count($errors) > 0)
            <div class="alert alert-danger alert-dismissible fade show" role="alert">
                @foreach ($errors->all() as $error)
                    <span class="alert-icon"><i class="ni ni-fat-remove"></i></span>
                    <span class="alert-text"><strong>Error! </strong>{{ $error }}</span>
                @endforeach
                <button type="button" class="close" data-dismiss="alert" aria-label="Close">
                    <span aria-hidden="true">×</span>
                </button>
            </div>
        @endif
        @if (session('confirmation'))
            <div class="alert alert-info" role="alert">
                {!! session('confirmation') !!}
            </div>
        @endif

        @if ($errors->has('confirmation') > 0 )
            <div class="alert alert-danger" role="alert">
                {!! $errors->first('confirmation') !!}
            </div>
        @endif

        @php
            $code = \Request::get('code');
            $state = \Request::get('state');
            $instanceId = \Request::get('instanceId');

            if(!empty($code) && !empty($state) && !empty($instanceId))
            {
                wixAuthorizationCode($state, $code, $instanceId);
            }
        @endphp
        <form role="form" action="{{ route('login') }}" method="POST">
            @csrf

            <div class="form-group mb-3" id="emailGroup">
                <div class="input-group input-group-merge input-group-alternative">
                    <div class="input-group-prepend">
                        <span class="input-group-text"><i class="ni ni-email-83"></i></span>
                    </div>
                    <input type="email" name="email" id="email" value="{{ old('email') }}" placeholder="{{ __('E-Mail Address') }}" class="form-control @error('email') is-invalid @enderror" required autocomplete="email" autofocus>
                </div>
                @error('email')
                    <div class="invalid-feedback d-block">
                        {{ $message }}
                    </div>
                @enderror
            </div>

            <div class="form-group" id="passwordGroup">
                <div class="input-group input-group-merge input-group-alternative">
                    <div class="input-group-prepend">
                        <span class="input-group-text"><i class="ni ni-lock-circle-open"></i></span>
                    </div>
                    <input type="password" name="password" placeholder="Password" class="form-control @error('password') is-invalid @enderror" required autocomplete="current-password">
                </div>
                @error('password')
                    <div class="invalid-feedback d-block">
                        {{ $message }}
                    </div>
                @enderror
            </div>

            <div class="custom-control custom-control-alternative custom-checkbox">
                <input class="custom-control-input" id=" customCheckLogin" type="checkbox"  name="remember" value="1">
                <label class="custom-control-label" for=" customCheckLogin">
                    <span class="text-muted">Remember Me</span>
                </label>
            </div>

            <div class="text-center">
                <button type="submit" class="btn btn-primary my-4">
                    <span class="signingin d-none">
                        Logging in...
                    </span>
                    <span class="signin">
                        Login
                    </span>
                </button>
            </div>
        </form>
    </div>
</div>

<div class="modal fade" id="activation_notification" tabindex="-1" role="dialog" aria-labelledby="modal-notification" aria-hidden="true">
    <div class="modal-dialog modal-danger modal-dialog-centered modal-" role="document">
        <div class="modal-content bg-gradient-danger">
            <div class="modal-header">
                <h6 class="modal-title" id="modal-title-notification">Your attention is required</h6>
                <button type="button" class="close" data-dismiss="modal" aria-label="Close">
                    <span aria-hidden="true">×</span>
                </button>
            </div>
            <div class="modal-body">
                <div class="py-3 text-center">
                    <i class="ni ni-bell-55 ni-2x"></i>
                    <h4 class="heading mt-4">You should read this!</h4>
                    <p>Currently, your account is not active our representative shortly contact you. And active of your account.</p>
                    <div class="pt-2 text-left">
                        Regards,<br>
                        <b>Web4jeweler</b>
                    </div>
                </div>
            </div>
            <div class="modal-footer">
                <button type="button" class="btn btn-white" data-dismiss="modal">Ok, Got it</button>
                {{-- <button type="button" class="btn btn-link text-white ml-auto" data-dismiss="modal">Close</button> --}}
            </div>
        </div>
    </div>
</div>
@endsection

@section('page_js')
    <script>
        $(function(){
            var activation = '{{ \Session::get('activation') }}';
            if(activation)
            {
                $('#activation_notification').modal('show');
            }
        });
        var btn = document.querySelector('button[type="submit"]');
        var form = document.forms[0];
        var email = document.querySelector('[name="email"]');
        var password = document.querySelector('[name="password"]');
        btn.addEventListener('click', function(ev){
            if (form.checkValidity()) {
                btn.querySelector('.signingin').className = 'signingin';
                btn.querySelector('.signin').className = 'signin d-none';
            } else {
                ev.preventDefault();
            }
        });
        email.focus();
        document.getElementById('emailGroup').classList.add("focused");

        // Focus events for email and password fields
        email.addEventListener('focusin', function(e){
            document.getElementById('emailGroup').classList.add("focused");
        });
        email.addEventListener('focusout', function(e){
            document.getElementById('emailGroup').classList.remove("focused");
        });

        password.addEventListener('focusin', function(e){
            document.getElementById('passwordGroup').classList.add("focused");
        });
        password.addEventListener('focusout', function(e){
            document.getElementById('passwordGroup').classList.remove("focused");
        });
    </script>
@endsection
