@extends('layouts.app')
@section('pagetitle', ' | '.$pagetitle)

@section('page_css')
<link rel="stylesheet" href="{{ url('public/argon-dashboard/assets/vendor/select2/dist/css/select2.min.css') }}">
@endsection

@section('content')
<!-- Header -->
<div class="header bg-primary pb-6">
    <div class="container-fluid">
        <div class="header-body">
            <div class="row align-items-center py-4">
                <div class="col-lg-6 col-7">
                    <h6 class="h2 text-white d-inline-block mb-0">Settings Management</h6>
                    <nav aria-label="breadcrumb" class="d-none d-md-inline-block ml-md-4">
                        <ol class="breadcrumb breadcrumb-links breadcrumb-dark">
                            <li class="breadcrumb-item"><a href="#"><i class="fas fa-home"></i></a></li>
                            @php
                            $total = count($breadcrumbs);
                            $active = $total-1;
                            @endphp
                            @foreach ($breadcrumbs as $key => $item)
                                @if ($key == $active)
                                    <li class="breadcrumb-item active" aria-current="page">
                                        <a href="{{ url($urls[$key]) }}">{{$item}}</a>
                                    </li>
                                @else
                                    <li class="breadcrumb-item">
                                        <a href="{{ url($urls[$key]) }}">{{$item}}</a>
                                    </li>
                                @endif
                            @endforeach
                        </ol>
                    </nav>
                </div>
                <div class="col-lg-6 col-5 text-right">
                    {{-- @if(Auth::user()->hasPermissionTo('role-create'))
                        <a href="{{url('/roles-management/role-create')}}" class="btn btn-sm btn-neutral">
                            <i class="ni ni-fat-add"></i>
                            Add
                        </a>
                    @endif --}}
                </div>
            </div>
        </div>
    </div>
</div>
<!-- Page content -->
<div class="container-fluid mt--6">
    <!-- Table -->
    <div class="row">
        <div class="col">
            <div class="card">
                <!-- Card header -->
                <div class="card-header bg-gradient-red text-white">
                    <h3 class="mb-0">How To Use:</h3>
                    <p class="text-sm mb-0">You can get the value of each setting anywhere on site by calling  <code> get_setting('group.key')</code> </p>
                </div>
                <div class="card-body">
                    @if (count($errors) > 0)
                        <div class="alert alert-danger alert-dismissible fade show" role="alert">
                            @foreach ($errors->all() as $error)
                                <span class="alert-icon"><i class="ni ni-fat-remove"></i></span>
                                <span class="alert-text"><strong>Error! </strong>{{ $error }}</span>
                            @endforeach
                            <button type="button" class="close" data-dismiss="alert" aria-label="Close">
                                <span aria-hidden="true">×</span>
                            </button>
                        </div>
                    @endif
                    @foreach ($settings as $setting)
                        <form class="needs-validation @if (count($errors) > 0) was-validated @endif" action="{{ url('/settings/setting-update', $setting->id) }}" id="#form_{{$setting->id}}" method="POST" enctype="multipart/form-data" novalidate>
                            @csrf
                            <div class="form-row mb-3">
                                <div class="col-md-6 mb-3">
                                    <label class="form-control-label" for="value">{{$setting->name}}</label><code> get_setting('{{$setting->key}}')</code>
                                    @if ($setting->type == 'text')
                                        <input type="text" class="form-control"  name="value" placeholder="{{$setting->name}}" value="{{$setting->value}}">
                                        @error('value')
                                            <div class="invalid-feedback">
                                                {{ $message }}
                                            </div>
                                        @enderror
                                    @elseif ($setting->type == 'image')
                                        <img class="avatar avatar-sm rounded-circle" src="{{ asset('public/storage/'.$setting->value) }}" alt="">
                                        <input type="file" class="form-control"  name="image">
                                        @error('value')
                                            <div class="invalid-feedback">
                                                {{ $message }}
                                            </div>
                                        @enderror
                                    @endif
                                </div>
                                <div class="col-md-3 mb-3">
                                    <label class="form-control-label" for="group">Group</label>
                                    <select class="form-control group" data-toggle="select" name="group" required>
                                        <option value="admin" @if($setting->group == 'Admin') selected @endif>Admin</option>
                                        <option value="site" @if($setting->group == 'Site') selected @endif>Site</option>
                                    </select>
                                    @error('group')
                                        <div class="invalid-feedback d-block">
                                            {{ $message }}
                                        </div>
                                    @enderror
                                </div>
                                <div class="col-md-3 mt-4">
                                    <div class='btn-toolbar'>
                                        @if(Auth::user()->hasPermissionTo('setting-edit'))
                                            <button type="submit" class="btn btn-outline-primary btn-icon-only" data-toggle="tooltip" title="Save"><i class="fa fa-edit"></i></button>
                                        @endif
                                        @if(Auth::user()->hasPermissionTo('setting-delete'))
                                            <a href="{{ url('/settings/setting-delete', $setting->id) }}" class="btn btn-outline-danger btn-icon-only" data-toggle="tooltip" title="Delete"><i class="fa fa-trash"></i></a>
                                        @endif
                                    </div>
                                </div>
                            </div>
                        </form>
                    @endforeach
                </div>
            </div>
        </div>
    </div>
    <!-- Table -->
    @if(Auth::user()->hasPermissionTo('setting-create'))
    <div class="row">
        <div class="col">
            <div class="card">
                <!-- Card header -->
                <div class="card-header bg-gradient-success">
                    <h3 class="mb-0">New Settings</h3>
                    <p class="text-sm mb-0"></p>
                </div>
                <div class="card-body">
                    @if (count($errors) > 0)
                        <div class="alert alert-danger alert-dismissible fade show" role="alert">
                            @foreach ($errors->all() as $error)
                                <span class="alert-icon"><i class="ni ni-fat-remove"></i></span>
                                <span class="alert-text"><strong>Error! </strong>{{ $error }}</span>
                            @endforeach
                            <button type="button" class="close" data-dismiss="alert" aria-label="Close">
                                <span aria-hidden="true">×</span>
                            </button>
                        </div>
                    @endif
                    <form class="needs-validation @if (count($errors) > 0) was-validated @endif" action="{{url('/settings/setting-store')}}" enctype="multipart/form-data" method="POST" novalidate>
                        @csrf
                        <div class="form-row">
                            <div class="col-md-3 mb-3">
                                <label class="form-control-label" for="name">Name</label>
                                <input type="text" class="form-control" id="name"  name="name" placeholder="Setting name ex: Admin Title" required>
                                @error('name')
                                    <div class="invalid-feedback">
                                        {{ $message }}
                                    </div>
                                @enderror
                            </div>
                            <div class="col-md-3 mb-3">
                                <label class="form-control-label" for="key">Key</label>
                                <input type="text" class="form-control" id="key"  name="key" placeholder="Setting key ex: admin_title" required>
                                @error('key')
                                    <div class="invalid-feedback">
                                        {{ $message }}
                                    </div>
                                @enderror
                            </div>
                            <div class="col-md-3 mb-3">
                                <label class="form-control-label" for="type">Type</label>
                                <select class="form-control" data-toggle="select" name="type" id="type" required>
                                    <option></option>
                                    <option value="text">Text Box</option>
                                    <option value="image">File</option>
                                </select>
                                @error('type')
                                    <div class="invalid-feedback d-block">
                                        {{ $message }}
                                    </div>
                                @enderror
                            </div>
                            <div class="col-md-3 mb-3">
                                <label class="form-control-label" for="group">Group</label>
                                <select class="form-control" data-toggle="select" name="group" id="group" required>
                                    <option></option>
                                    <option value="admin">Admin</option>
                                    <option value="site">Site</option>
                                </select>
                                @error('group')
                                    <div class="invalid-feedback d-block">
                                        {{ $message }}
                                    </div>
                                @enderror
                            </div>
                        </div>
                        <button class="btn btn-primary" type="submit">Add New Setting</button>
                    </form>
                </div>
            </div>
        </div>
    </div>
    @endif
@endsection
@section('page_js')
<script src="{{ url('public/argon-dashboard/assets/vendor/select2/dist/js/select2.min.js') }}"></script>
<script>
    $( document ).ready(function() {

        //assigne Type dropdown place holder 
        $("#type").select2({
            placeholder: "Select a Type",
            allowClear: true
        });

        //assigne Group dropdown place holder 
        $("#group").select2({
            placeholder: "Select a Group",
            allowClear: true
        });
    });
</script>
@endsection