@extends('layouts.app')
@section('pagetitle', ' | '.$pagetitle)

@section('page_css')
<link rel="stylesheet" href="{{ url('public/argon-dashboard/assets/vendor/select2/dist/css/select2.min.css') }}">
@endsection

@section('content')
<!-- Header -->
<div class="header bg-primary pb-6">
    <div class="container-fluid">
        <div class="header-body">
            <div class="row align-items-center py-4">
                <div class="col-lg-6 col-7">
                    <h6 class="h2 text-white d-inline-block mb-0">Users Management</h6>
                    <nav aria-label="breadcrumb" class="d-none d-md-inline-block ml-md-4">
                        <ol class="breadcrumb breadcrumb-links breadcrumb-dark">
                            <li class="breadcrumb-item"><a href="#"><i class="fas fa-home"></i></a></li>
                            @php
                            $total = count($breadcrumbs);
                            $active = $total-1;
                            @endphp
                            @foreach ($breadcrumbs as $key => $item)
                                @if ($key == $active)
                                    <li class="breadcrumb-item active" aria-current="page">
                                        <a href="{{ url($urls[$key]) }}">{{$item}}</a>
                                    </li>
                                @else
                                    <li class="breadcrumb-item">
                                        <a href="{{ url($urls[$key]) }}">{{$item}}</a>
                                    </li>
                                @endif
                            @endforeach
                        </ol>
                    </nav>
                </div>
                <div class="col-lg-6 col-5 text-right">
                </div>
            </div>
        </div>
    </div>
</div>
<!-- Page content -->
<div class="container-fluid mt--6">
    <!-- Table -->
    <div class="row">
        <div class="col">
            <div class="card">
                <!-- Card header -->
                <div class="card-header">
                    <h3 class="mb-0"></h3>
                    <p class="text-sm mb-0"></p>
                </div>
                <div class="card-body">
                    @if (count($errors) > 0)
                        <div class="alert alert-danger alert-dismissible fade show" role="alert">
                            @foreach ($errors->all() as $error)
                                <span class="alert-icon"><i class="ni ni-fat-remove"></i></span>
                                <span class="alert-text"><strong>Error! </strong>{{ $error }}</span>
                            @endforeach
                            <button type="button" class="close" data-dismiss="alert" aria-label="Close">
                                <span aria-hidden="true">×</span>
                            </button>
                        </div>
                    @endif
                    <form class="needs-validation @if (count($errors) > 0) was-validated @endif" action="{{url('/users-management/user-profile-update/'.$user->id)}}" enctype="multipart/form-data" method="POST" novalidate>
                        @csrf
                        <div class="form-row">
                            <div class="col-md-6 mb-3">
                                <label class="form-control-label" for="first_name">First Name</label>
                                <input type="text" class="form-control" id="first_name"  name="first_name" placeholder="First Name" required value="{{ $user->first_name }}">
                                @error('first_name')
                                    <div class="invalid-feedback">
                                        {{ $message }}
                                    </div>
                                @enderror
                            </div>
                            <div class="col-md-6 mb-3">
                                <label class="form-control-label" for="last_name">Last Name</label>
                                <input type="text" class="form-control" id="last_name"  name="last_name" placeholder="Last Name" required value="{{ $user->last_name }}">
                                @error('last_name')
                                    <div class="invalid-feedback">
                                        {{ $message }}
                                    </div>
                                @enderror
                            </div>
                        </div>
                        <div class="form-row">
                            <div class="col-md-6 mb-3">
                                <label class="form-control-label" for="email">Email</label>
                                <input type="email" name="email" id="email" placeholder="Email" class="form-control" required value="{{ $user->email }}">
                                @error('email')
                                    <div class="invalid-feedback">
                                        {{ $message }}
                                    </div>
                                @enderror
                            </div>
                            <div class="col-md-6 mb-3">
                                <label class="form-control-label" for="phone">Phone</label>
                                <input type="text" name="phone" id="phone" class="form-control" required value="{{ $user->addresses[0]->phone }}">
                                @error('phone')
                                    <div class="invalid-feedback">
                                        {{ $message }}
                                    </div>
                                @enderror
                            </div>
                        </div>
                        <div class="form-row">
                            <div class="col-md-8 mb-3">
                                <label class="form-control-label" for="address">Address</label>
                                <input type="text" name="address" id="address" placeholder="Street Address" class="form-control" required value="{{ $user->addresses[0]->street1 }}">
                                @error('address')
                                    <div class="invalid-feedback">
                                        {{ $message }}
                                    </div>
                                @enderror
                            </div>
                            <div class="col-md-4 mb-3">
                                <label class="form-control-label" for="zip">Zip Code</label>
                                <input type="text" name="zip" id="zip" placeholder="Zip Code" class="form-control" required value="{{ $user->addresses[0]->zip }}">
                                @error('zip')
                                    <div class="invalid-feedback">
                                        {{ $message }}
                                    </div>
                                @enderror
                            </div>
                        </div>
                        <div class="form-row">
                            <div class="col-md-6 mb-3">
                                <label class="form-control-label" for="unit">Unit</label>
                                <input type="text" name="unit" id="unit" placeholder="Unit" class="form-control" required value="{{ $user->addresses[0]->unit }}">
                                @error('unit')
                                    <div class="invalid-feedback">
                                        {{ $message }}
                                    </div>
                                @enderror
                            </div>
                            <div class="col-md-6 mb-3">
                                <label class="form-control-label" for="company">Company</label>
                                <input type="text" name="company" id="company" placeholder="company" class="form-control" required value="{{ $user->addresses[0]->company }}">
                                @error('company')
                                    <div class="invalid-feedback">
                                        {{ $message }}
                                    </div>
                                @enderror
                            </div>
                        </div>
                        <div class="form-row">
                            <div class="col-md-6 mb-3">
                                <label class="form-control-label" for="country">Country</label>
                                @php
                                    $countries = countries();
                                    $selected = $user->addresses[0]->country;
                                @endphp
                                <select class="form-control" data-toggle="select" name="country" id="country" onchange="states(this.value)">
                                    <option></option>
                                    @foreach ($countries as $country)
                                        <option value="{{$country->name}}" @if ($country->name == $selected)selected @endif>{{$country->name}}</option>
                                    @endforeach
                                </select>
                                @error('country')
                                    <div class="invalid-feedback">
                                        {{ $message }}
                                    </div>
                                @enderror
                            </div>
                            <div class="col-md-6 mb-3">
                                <label class="form-control-label" for="state">State</label>
                                <select class="form-control" data-toggle="select" name="state" id="state" onchange="cities(this.value)">
                                    <option></option>
                                </select>
                                @error('state')
                                    <div class="invalid-feedback">
                                        {{ $message }}
                                    </div>
                                @enderror
                            </div>
                        </div>
                        <div class="form-row">
                            <div class="col-md-6 mb-3">
                                <label class="form-control-label" for="city">City</label>
                                <select class="form-control" data-toggle="select" name="city" id="city">
                                    <option></option>
                                </select>
                                @error('city')
                                    <div class="invalid-feedback">
                                        {{ $message }}
                                    </div>
                                @enderror
                            </div>
                            <div class="col-md-6 mb-3">
                                <label class="form-control-label" for="roles">Profile Image</label>
                                @if ($user->avatar)
                                    <img class="avatar avatar-sm rounded-circle" src="{{ asset('public/storage/'.$user->avatar) }}" alt="">
                                    <input type="file" class="form-control"  name="image">
                                    @error('image')
                                        <div class="invalid-feedback">
                                            {{ $message }}
                                        </div>
                                    @enderror
                                @endif
                            </div>
                        </div>
                        <div class="form-row">
                            <div class="col-md-6 mb-3">
                                <label class="form-control-label" for="password">Password</label>
                                <input type="password" name="password" placeholder="Password" class="form-control" required>
                                @error('password')
                                    <div class="invalid-feedback">
                                        {{ $message }}
                                    </div>
                                @enderror
                            </div>
                            <div class="col-md-6 mb-3">
                                <label class="form-control-label" for="password_confirmation">Confirm Password</label>
                                <input type="password" name="password_confirmation" placeholder="Confirm Password" class="form-control" required>
                                @error('password_confirmation')
                                    <div class="invalid-feedback">
                                        {{ $message }}
                                    </div>
                                @enderror
                            </div>
                        </div>
                        <button class="btn btn-primary" type="submit">Update Profile</button>
                    </form>
                </div>
            </div>
        </div>
    </div>
@endsection
@section('page_js')
<script src="{{ url('public/argon-dashboard/assets/vendor/select2/dist/js/select2.min.js') }}"></script>
<script>
    $( document ).ready(function() {

        //assigne Country dropdown place holder 
        $("#country").select2({
            placeholder: "Select a Country",
            allowClear: true
        });

        //assigne State dropdown place holder
        $("#state").select2({
            placeholder: "Select a State",
            allowClear: true
        });

        //assigne City dropdown place holder
        $("#city").select2({
            placeholder: "Select a City",
            allowClear: true
        });

        //assigne Role dropdown place holder
        $("#roles").select2({
            placeholder: "Select a Role",
            allowClear: true
        });

        //get Country value and call states function
        var country = $("#country").val();
        states(country,'{!!$user->addresses[0]->state!!}');
        setTimeout(function(){
            var state = $("#state").val();
            cities(state,'{!!$user->addresses[0]->city!!}');
        }, 300);
    });

    //get states agains selectd countery.
    function states(obj, selected='')
    {
        var url = "{!!url('/load-states')!!}";
        $.ajax({
            type:'POST',
            url:url,
            data:{ 'country': obj, 'selected': selected, '_token': '{{ csrf_token() }}'},
            dataType:'json',
            success:function(data){
                if(data.status == true)
                {
                    $('#state').html(data.html);
                };
            },
            error:function(data){
                if(data.status == 'false')
                {
                }
            }
        });
    }

    //get Cities agains selectd State.
    function cities(obj, selected='')
    {
        var url = "{!!url('/load-cities')!!}";
        $.ajax({
            type:'POST',
            url:url,
            data:{ 'state': obj, 'selected': selected, '_token': '{{ csrf_token() }}'},
            dataType:'json',
            success:function(data){
                if(data.status == true)
                {
                    $('#city').html(data.html);
                };
            },
            error:function(data){
                if(data.status == 'false')
                {
                }
            }
        });
    }
</script>
@endsection