<?php

use Illuminate\Support\Facades\Route;
use Illuminate\Http\Request;

/*
|--------------------------------------------------------------------------
| Web Routes
|--------------------------------------------------------------------------
|
| Here is where you can register web routes for your application. These
| routes are loaded by the RouteServiceProvider within a group which
| contains the "web" middleware group. Now create something great!
|
*/

Route::get('/', function () {
    return view('auth.login');
});

// Route::get('/email-verify', function () {
//     return view('authentication.verify-email');
// });

// Route::get('/verify-logout', function(){
//     Auth::logout();
// });

Route::get('/subscriptions', 'FrontEndController@subscriptions');
Route::post('/load-states', 'CountryController@loadStates');
Route::post('/load-cities', 'StateController@loadCities');
Route::get('/install','WebHooksController@appInstall');
Route::get('/products-sync','CronJobController@create');
Route::get('/products-update','CronJobController@productsUpdate');
Route::get('/products-recheck','CronJobController@productsRecheck');
Route::get('/password-make', 'CronJobController@passwordHash');
Route::get('/usesr-id-encrypt', 'CronJobController@usesrIdEncrypt');

Auth::routes(['verify' => true]);

Route::get('/home', 'HomeController@index')->name('home');

Route::group(['middleware' => ['auth']], function() {
    
    //Role Routes start here
    Route::group(['prefix' => 'roles-management'], function () {
        Route::get('/','RoleController@index');
        Route::get('role-list','RoleController@index');
        Route::get('role-ajax-data','RoleController@ajaxRoleData');
        Route::get('role-create','RoleController@create');
        Route::Post('role-store','RoleController@store');
        Route::get('role-show/{id}','RoleController@show');
        Route::get('role-edit/{id}','RoleController@edit');
        Route::post('role-update/{id}','RoleController@update');
        Route::delete('role-delete/{id}','RoleController@destroy');
    });
    //Role Routes End here

    //Permission Routes start here
    Route::group(['prefix' => 'permissions-management'], function () {
        Route::get('/','PermissionsController@index');
        Route::get('permission-list','PermissionsController@index');
        Route::get('permission-ajax-data','PermissionsController@ajaxPermissionData');
        Route::get('permission-create','PermissionsController@create');
        Route::Post('permission-store','PermissionsController@store');
        Route::get('permission-show/{id}','PermissionsController@show');
        Route::get('permission-edit/{id}','PermissionsController@edit');
        Route::post('permission-update/{id}','PermissionsController@update');
        Route::delete('permission-delete/{id}','PermissionsController@destroy');
    });
    //Permission Routes End here

    //User Routes start here
    Route::group(['prefix' => 'users-management'], function () {
        Route::get('/','UserController@index');
        Route::get('user-list','UserController@index');
        Route::get('user-ajax-data','UserController@ajaxUserData');
        Route::get('user-create','UserController@create');
        Route::Post('user-store','UserController@store');
        Route::get('user-show/{id}','UserController@show');
        Route::get('user-edit/{id}','UserController@edit');
        Route::post('user-update/{id}','UserController@update');
        Route::delete('user-delete/{id}','UserController@destroy');
        Route::get('user-profile/{id}','UserController@profile');
        Route::post('user-profile-update/{id}','UserController@profile_update');
        Route::get('user-status/{id}','UserController@status');
    });
    //User Routes End here

    //Settings Routes start here
    Route::group(['prefix' => 'settings'], function () {
        Route::get('/','SettingsController@index');
        Route::get('setting-list','SettingsController@index');
        Route::get('setting-ajax-data','SettingsController@ajaxSettingData');
        Route::get('setting-create','SettingsController@create');
        Route::Post('setting-store','SettingsController@store');
        Route::get('setting-show/{id}','SettingsController@show');
        Route::get('setting-edit/{id}','SettingsController@edit');
        Route::post('setting-update/{id}','SettingsController@update');
        Route::get('setting-delete/{id}','SettingsController@destroy');
    });
    //Settings Routes End here

    //Social Settings Routes start here
    Route::group(['prefix' => 'social-settings'], function () {
        Route::get('/','SocialSettingsController@index');
        Route::get('social-setting-list','SocialSettingsController@index');
        Route::get('social-setting-ajax-data','SocialSettingsController@ajaxSocialData');
        Route::get('social-setting-create','SocialSettingsController@create');
        Route::Post('social-setting-store','SocialSettingsController@store');
        Route::get('social-setting-show/{id}','SocialSettingsController@show');
        Route::get('social-setting-edit/{id}','SocialSettingsController@edit');
        Route::post('social-setting-update/{id}','SocialSettingsController@update');
        Route::get('social-setting-delete/{id}','SocialSettingsController@destroy');
    });
    //Social Settings Routes End here

    //Store Filters Routes start here
    Route::group(['prefix' => 'store-filters'], function () {
        Route::get('/','StoreFiltersController@index');
        Route::get('store-filter-list','StoreFiltersController@index');
        Route::get('store-filter-ajax-data','StoreFiltersController@ajaxFiltersData');
        Route::get('store-filter-create','StoreFiltersController@create');
        Route::Post('store-filter-store','StoreFiltersController@store');
        Route::get('store-filter-show/{id}','StoreFiltersController@show');
        Route::get('store-filter-edit/{id}','StoreFiltersController@edit');
        Route::post('store-filter-update/{id}','StoreFiltersController@update');
        Route::get('store-filter-delete/{id}','StoreFiltersController@destroy');
    });
    //Store Filters Routes End here

    //Category Routes start here
    Route::group(['prefix' => 'categories'], function () {
        Route::get('/','CategoriesController@index');
        Route::get('category-list','CategoriesController@index');
        Route::get('category-ajax-data','CategoriesController@ajaxCategoryData');
        Route::get('category-create','CategoriesController@create');
        Route::get('category-upload','CategoriesController@upload');
        Route::post('category-upload-csv','CategoriesController@uploadData');
        Route::Post('category-store','CategoriesController@store');
        Route::get('category-show/{id}','CategoriesController@show');
        Route::get('category-edit/{id}','CategoriesController@edit');
        Route::get('category-update','CategoriesController@categoriesUpdate');
        Route::get('category-delete','CategoriesController@destroy');
    });
    //Category Routes End here

    //Product Routes start here
    Route::group(['prefix' => 'products'], function () {
        Route::get('/','ProductsController@index');
        Route::get('product-list','ProductsController@index');
        Route::get('product-ajax-data','ProductsController@ajaxProductsData');
        Route::get('product-create','ProductsController@create');
        Route::get('product-upload','ProductsController@upload');
        Route::post('product-upload-csv','ProductsController@uploadData');
        Route::Post('product-store','ProductsController@store');
        Route::get('product-show/{id}','ProductsController@show');
        Route::get('product-edit/{id}','ProductsController@edit');
        Route::get('product-update','ProductsController@productsUpdate');
        Route::get('product-delete','ProductsController@productsRemove');
    });
    //Product Routes End here

    //categories filter Routes Start here
    Route::group(['prefix' => 'categories-filter'], function () {
        Route::get('/','CategoryFilterController@index');
        Route::get('filter-list','CategoryFilterController@index');
        Route::get('filter-ajax-data','CategoryFilterController@ajaxCategoryFilterData');
        Route::get('filter-create','CategoryFilterController@create');
        Route::Post('filter-store','CategoryFilterController@store');
    });
    //categories filter Routes End here
});
